# coding: utf-8

"""
    Demisto API

    This is the public REST API to integrate with the demisto server. HTTP request can be sent using any HTTP-client.  For an example dedicated client take a look at: https://github.com/demisto/demisto-py.  Requests must include API-key that can be generated in the Demisto web client under 'Settings' -> 'Integrations' -> 'API keys'   Optimistic Locking and Versioning\\:  When using Demisto REST API, you will need to make sure to work on the latest version of the item (incident, entry, etc.), otherwise, you will get a DB version error (which not allow you to override a newer item). In addition, you can pass 'version\\: -1' to force data override (make sure that other users data might be lost).  Assume that Alice and Bob both read the same data from Demisto server, then they both changed the data, and then both tried to write the new versions back to the server. Whose changes should be saved? Alice’s? Bob’s? To solve this, each data item in Demisto has a numeric incremental version. If Alice saved an item with version 4 and Bob trying to save the same item with version 3, Demisto will rollback Bob request and returns a DB version conflict error. Bob will need to get the latest item and work on it so Alice work will not get lost.  Example request using 'curl'\\:  ``` curl 'https://hostname:443/incidents/search' -H 'content-type: application/json' -H 'accept: application/json' -H 'Authorization: <API Key goes here>' --data-binary '{\"filter\":{\"query\":\"-status:closed -category:job\",\"period\":{\"by\":\"day\",\"fromValue\":7}}}' --compressed ```  # noqa: E501

    OpenAPI spec version: 2.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from demisto_client.demisto_api.models.playbook_inputs import PlaybookInputs  # noqa: F401,E501
from demisto_client.demisto_api.models.playbook_outputs import PlaybookOutputs  # noqa: F401,E501
from demisto_client.demisto_api.models.playbook_task import PlaybookTask  # noqa: F401,E501
from demisto_client.demisto_api.models.playbook_view import PlaybookView  # noqa: F401,E501
from demisto_client.demisto_api.models.version import Version  # noqa: F401,E501


class Playbook(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'brands': 'list[str]',
        'commands': 'list[str]',
        'comment': 'str',
        'commit_message': 'str',
        'dbot_created_by': 'str',
        'detached': 'bool',
        'from_server_version': 'Version',
        'has_role': 'bool',
        'hidden': 'bool',
        'id': 'str',
        'inputs': 'PlaybookInputs',
        'item_version': 'Version',
        'locked': 'bool',
        'missing_scripts_ids': 'list[str]',
        'modified': 'datetime',
        'name': 'str',
        'name_raw': 'str',
        'outputs': 'PlaybookOutputs',
        'pack_id': 'str',
        'prev_name': 'str',
        'previous_roles': 'list[str]',
        'primary_term': 'int',
        'private': 'bool',
        'propagation_labels': 'list[str]',
        'quiet': 'bool',
        'roles': 'list[str]',
        'script_ids': 'list[str]',
        'sequence_number': 'int',
        'should_commit': 'bool',
        'sort_values': 'list[str]',
        'source_playbook_id': 'str',
        'start_task_id': 'str',
        'system': 'bool',
        'tags': 'list[str]',
        'task_ids': 'list[str]',
        'tasks': 'dict(str, PlaybookTask)',
        'to_server_version': 'Version',
        'vc_should_ignore': 'bool',
        'version': 'int',
        'view': 'PlaybookView'
    }

    attribute_map = {
        'brands': 'brands',
        'commands': 'commands',
        'comment': 'comment',
        'commit_message': 'commitMessage',
        'dbot_created_by': 'dbotCreatedBy',
        'detached': 'detached',
        'from_server_version': 'fromServerVersion',
        'has_role': 'hasRole',
        'hidden': 'hidden',
        'id': 'id',
        'inputs': 'inputs',
        'item_version': 'itemVersion',
        'locked': 'locked',
        'missing_scripts_ids': 'missingScriptsIds',
        'modified': 'modified',
        'name': 'name',
        'name_raw': 'nameRaw',
        'outputs': 'outputs',
        'pack_id': 'packID',
        'prev_name': 'prevName',
        'previous_roles': 'previousRoles',
        'primary_term': 'primaryTerm',
        'private': 'private',
        'propagation_labels': 'propagationLabels',
        'quiet': 'quiet',
        'roles': 'roles',
        'script_ids': 'scriptIds',
        'sequence_number': 'sequenceNumber',
        'should_commit': 'shouldCommit',
        'sort_values': 'sortValues',
        'source_playbook_id': 'sourcePlaybookID',
        'start_task_id': 'startTaskId',
        'system': 'system',
        'tags': 'tags',
        'task_ids': 'taskIds',
        'tasks': 'tasks',
        'to_server_version': 'toServerVersion',
        'vc_should_ignore': 'vcShouldIgnore',
        'version': 'version',
        'view': 'view'
    }

    def __init__(self, brands=None, commands=None, comment=None, commit_message=None, dbot_created_by=None, detached=None, from_server_version=None, has_role=None, hidden=None, id=None, inputs=None, item_version=None, locked=None, missing_scripts_ids=None, modified=None, name=None, name_raw=None, outputs=None, pack_id=None, prev_name=None, previous_roles=None, primary_term=None, private=None, propagation_labels=None, quiet=None, roles=None, script_ids=None, sequence_number=None, should_commit=None, sort_values=None, source_playbook_id=None, start_task_id=None, system=None, tags=None, task_ids=None, tasks=None, to_server_version=None, vc_should_ignore=None, version=None, view=None):  # noqa: E501
        """Playbook - a model defined in Swagger"""  # noqa: E501

        self._brands = None
        self._commands = None
        self._comment = None
        self._commit_message = None
        self._dbot_created_by = None
        self._detached = None
        self._from_server_version = None
        self._has_role = None
        self._hidden = None
        self._id = None
        self._inputs = None
        self._item_version = None
        self._locked = None
        self._missing_scripts_ids = None
        self._modified = None
        self._name = None
        self._name_raw = None
        self._outputs = None
        self._pack_id = None
        self._prev_name = None
        self._previous_roles = None
        self._primary_term = None
        self._private = None
        self._propagation_labels = None
        self._quiet = None
        self._roles = None
        self._script_ids = None
        self._sequence_number = None
        self._should_commit = None
        self._sort_values = None
        self._source_playbook_id = None
        self._start_task_id = None
        self._system = None
        self._tags = None
        self._task_ids = None
        self._tasks = None
        self._to_server_version = None
        self._vc_should_ignore = None
        self._version = None
        self._view = None
        self.discriminator = None

        if brands is not None:
            self.brands = brands
        if commands is not None:
            self.commands = commands
        if comment is not None:
            self.comment = comment
        if commit_message is not None:
            self.commit_message = commit_message
        if dbot_created_by is not None:
            self.dbot_created_by = dbot_created_by
        if detached is not None:
            self.detached = detached
        if from_server_version is not None:
            self.from_server_version = from_server_version
        if has_role is not None:
            self.has_role = has_role
        if hidden is not None:
            self.hidden = hidden
        if id is not None:
            self.id = id
        if inputs is not None:
            self.inputs = inputs
        if item_version is not None:
            self.item_version = item_version
        if locked is not None:
            self.locked = locked
        if missing_scripts_ids is not None:
            self.missing_scripts_ids = missing_scripts_ids
        if modified is not None:
            self.modified = modified
        if name is not None:
            self.name = name
        if name_raw is not None:
            self.name_raw = name_raw
        if outputs is not None:
            self.outputs = outputs
        if pack_id is not None:
            self.pack_id = pack_id
        if prev_name is not None:
            self.prev_name = prev_name
        if previous_roles is not None:
            self.previous_roles = previous_roles
        if primary_term is not None:
            self.primary_term = primary_term
        if private is not None:
            self.private = private
        if propagation_labels is not None:
            self.propagation_labels = propagation_labels
        if quiet is not None:
            self.quiet = quiet
        if roles is not None:
            self.roles = roles
        if script_ids is not None:
            self.script_ids = script_ids
        if sequence_number is not None:
            self.sequence_number = sequence_number
        if should_commit is not None:
            self.should_commit = should_commit
        if sort_values is not None:
            self.sort_values = sort_values
        if source_playbook_id is not None:
            self.source_playbook_id = source_playbook_id
        if start_task_id is not None:
            self.start_task_id = start_task_id
        if system is not None:
            self.system = system
        if tags is not None:
            self.tags = tags
        if task_ids is not None:
            self.task_ids = task_ids
        if tasks is not None:
            self.tasks = tasks
        if to_server_version is not None:
            self.to_server_version = to_server_version
        if vc_should_ignore is not None:
            self.vc_should_ignore = vc_should_ignore
        if version is not None:
            self.version = version
        if view is not None:
            self.view = view

    @property
    def brands(self):
        """Gets the brands of this Playbook.  # noqa: E501


        :return: The brands of this Playbook.  # noqa: E501
        :rtype: list[str]
        """
        return self._brands

    @brands.setter
    def brands(self, brands):
        """Sets the brands of this Playbook.


        :param brands: The brands of this Playbook.  # noqa: E501
        :type: list[str]
        """

        self._brands = brands

    @property
    def commands(self):
        """Gets the commands of this Playbook.  # noqa: E501


        :return: The commands of this Playbook.  # noqa: E501
        :rtype: list[str]
        """
        return self._commands

    @commands.setter
    def commands(self, commands):
        """Sets the commands of this Playbook.


        :param commands: The commands of this Playbook.  # noqa: E501
        :type: list[str]
        """

        self._commands = commands

    @property
    def comment(self):
        """Gets the comment of this Playbook.  # noqa: E501


        :return: The comment of this Playbook.  # noqa: E501
        :rtype: str
        """
        return self._comment

    @comment.setter
    def comment(self, comment):
        """Sets the comment of this Playbook.


        :param comment: The comment of this Playbook.  # noqa: E501
        :type: str
        """

        self._comment = comment

    @property
    def commit_message(self):
        """Gets the commit_message of this Playbook.  # noqa: E501


        :return: The commit_message of this Playbook.  # noqa: E501
        :rtype: str
        """
        return self._commit_message

    @commit_message.setter
    def commit_message(self, commit_message):
        """Sets the commit_message of this Playbook.


        :param commit_message: The commit_message of this Playbook.  # noqa: E501
        :type: str
        """

        self._commit_message = commit_message

    @property
    def dbot_created_by(self):
        """Gets the dbot_created_by of this Playbook.  # noqa: E501

        Who has created this event - relevant only for manual incidents  # noqa: E501

        :return: The dbot_created_by of this Playbook.  # noqa: E501
        :rtype: str
        """
        return self._dbot_created_by

    @dbot_created_by.setter
    def dbot_created_by(self, dbot_created_by):
        """Sets the dbot_created_by of this Playbook.

        Who has created this event - relevant only for manual incidents  # noqa: E501

        :param dbot_created_by: The dbot_created_by of this Playbook.  # noqa: E501
        :type: str
        """

        self._dbot_created_by = dbot_created_by

    @property
    def detached(self):
        """Gets the detached of this Playbook.  # noqa: E501


        :return: The detached of this Playbook.  # noqa: E501
        :rtype: bool
        """
        return self._detached

    @detached.setter
    def detached(self, detached):
        """Sets the detached of this Playbook.


        :param detached: The detached of this Playbook.  # noqa: E501
        :type: bool
        """

        self._detached = detached

    @property
    def from_server_version(self):
        """Gets the from_server_version of this Playbook.  # noqa: E501


        :return: The from_server_version of this Playbook.  # noqa: E501
        :rtype: Version
        """
        return self._from_server_version

    @from_server_version.setter
    def from_server_version(self, from_server_version):
        """Sets the from_server_version of this Playbook.


        :param from_server_version: The from_server_version of this Playbook.  # noqa: E501
        :type: Version
        """

        self._from_server_version = from_server_version

    @property
    def has_role(self):
        """Gets the has_role of this Playbook.  # noqa: E501

        Internal field to make queries on role faster  # noqa: E501

        :return: The has_role of this Playbook.  # noqa: E501
        :rtype: bool
        """
        return self._has_role

    @has_role.setter
    def has_role(self, has_role):
        """Sets the has_role of this Playbook.

        Internal field to make queries on role faster  # noqa: E501

        :param has_role: The has_role of this Playbook.  # noqa: E501
        :type: bool
        """

        self._has_role = has_role

    @property
    def hidden(self):
        """Gets the hidden of this Playbook.  # noqa: E501


        :return: The hidden of this Playbook.  # noqa: E501
        :rtype: bool
        """
        return self._hidden

    @hidden.setter
    def hidden(self, hidden):
        """Sets the hidden of this Playbook.


        :param hidden: The hidden of this Playbook.  # noqa: E501
        :type: bool
        """

        self._hidden = hidden

    @property
    def id(self):
        """Gets the id of this Playbook.  # noqa: E501


        :return: The id of this Playbook.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Playbook.


        :param id: The id of this Playbook.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def inputs(self):
        """Gets the inputs of this Playbook.  # noqa: E501


        :return: The inputs of this Playbook.  # noqa: E501
        :rtype: PlaybookInputs
        """
        return self._inputs

    @inputs.setter
    def inputs(self, inputs):
        """Sets the inputs of this Playbook.


        :param inputs: The inputs of this Playbook.  # noqa: E501
        :type: PlaybookInputs
        """

        self._inputs = inputs

    @property
    def item_version(self):
        """Gets the item_version of this Playbook.  # noqa: E501


        :return: The item_version of this Playbook.  # noqa: E501
        :rtype: Version
        """
        return self._item_version

    @item_version.setter
    def item_version(self, item_version):
        """Sets the item_version of this Playbook.


        :param item_version: The item_version of this Playbook.  # noqa: E501
        :type: Version
        """

        self._item_version = item_version

    @property
    def locked(self):
        """Gets the locked of this Playbook.  # noqa: E501


        :return: The locked of this Playbook.  # noqa: E501
        :rtype: bool
        """
        return self._locked

    @locked.setter
    def locked(self, locked):
        """Sets the locked of this Playbook.


        :param locked: The locked of this Playbook.  # noqa: E501
        :type: bool
        """

        self._locked = locked

    @property
    def missing_scripts_ids(self):
        """Gets the missing_scripts_ids of this Playbook.  # noqa: E501


        :return: The missing_scripts_ids of this Playbook.  # noqa: E501
        :rtype: list[str]
        """
        return self._missing_scripts_ids

    @missing_scripts_ids.setter
    def missing_scripts_ids(self, missing_scripts_ids):
        """Sets the missing_scripts_ids of this Playbook.


        :param missing_scripts_ids: The missing_scripts_ids of this Playbook.  # noqa: E501
        :type: list[str]
        """

        self._missing_scripts_ids = missing_scripts_ids

    @property
    def modified(self):
        """Gets the modified of this Playbook.  # noqa: E501


        :return: The modified of this Playbook.  # noqa: E501
        :rtype: datetime
        """
        return self._modified

    @modified.setter
    def modified(self, modified):
        """Sets the modified of this Playbook.


        :param modified: The modified of this Playbook.  # noqa: E501
        :type: datetime
        """

        self._modified = modified

    @property
    def name(self):
        """Gets the name of this Playbook.  # noqa: E501


        :return: The name of this Playbook.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Playbook.


        :param name: The name of this Playbook.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def name_raw(self):
        """Gets the name_raw of this Playbook.  # noqa: E501


        :return: The name_raw of this Playbook.  # noqa: E501
        :rtype: str
        """
        return self._name_raw

    @name_raw.setter
    def name_raw(self, name_raw):
        """Sets the name_raw of this Playbook.


        :param name_raw: The name_raw of this Playbook.  # noqa: E501
        :type: str
        """

        self._name_raw = name_raw

    @property
    def outputs(self):
        """Gets the outputs of this Playbook.  # noqa: E501


        :return: The outputs of this Playbook.  # noqa: E501
        :rtype: PlaybookOutputs
        """
        return self._outputs

    @outputs.setter
    def outputs(self, outputs):
        """Sets the outputs of this Playbook.


        :param outputs: The outputs of this Playbook.  # noqa: E501
        :type: PlaybookOutputs
        """

        self._outputs = outputs

    @property
    def pack_id(self):
        """Gets the pack_id of this Playbook.  # noqa: E501


        :return: The pack_id of this Playbook.  # noqa: E501
        :rtype: str
        """
        return self._pack_id

    @pack_id.setter
    def pack_id(self, pack_id):
        """Sets the pack_id of this Playbook.


        :param pack_id: The pack_id of this Playbook.  # noqa: E501
        :type: str
        """

        self._pack_id = pack_id

    @property
    def prev_name(self):
        """Gets the prev_name of this Playbook.  # noqa: E501


        :return: The prev_name of this Playbook.  # noqa: E501
        :rtype: str
        """
        return self._prev_name

    @prev_name.setter
    def prev_name(self, prev_name):
        """Sets the prev_name of this Playbook.


        :param prev_name: The prev_name of this Playbook.  # noqa: E501
        :type: str
        """

        self._prev_name = prev_name

    @property
    def previous_roles(self):
        """Gets the previous_roles of this Playbook.  # noqa: E501

        PreviousRoleName - do not change this field manually  # noqa: E501

        :return: The previous_roles of this Playbook.  # noqa: E501
        :rtype: list[str]
        """
        return self._previous_roles

    @previous_roles.setter
    def previous_roles(self, previous_roles):
        """Sets the previous_roles of this Playbook.

        PreviousRoleName - do not change this field manually  # noqa: E501

        :param previous_roles: The previous_roles of this Playbook.  # noqa: E501
        :type: list[str]
        """

        self._previous_roles = previous_roles

    @property
    def primary_term(self):
        """Gets the primary_term of this Playbook.  # noqa: E501


        :return: The primary_term of this Playbook.  # noqa: E501
        :rtype: int
        """
        return self._primary_term

    @primary_term.setter
    def primary_term(self, primary_term):
        """Sets the primary_term of this Playbook.


        :param primary_term: The primary_term of this Playbook.  # noqa: E501
        :type: int
        """

        self._primary_term = primary_term

    @property
    def private(self):
        """Gets the private of this Playbook.  # noqa: E501


        :return: The private of this Playbook.  # noqa: E501
        :rtype: bool
        """
        return self._private

    @private.setter
    def private(self, private):
        """Sets the private of this Playbook.


        :param private: The private of this Playbook.  # noqa: E501
        :type: bool
        """

        self._private = private

    @property
    def propagation_labels(self):
        """Gets the propagation_labels of this Playbook.  # noqa: E501


        :return: The propagation_labels of this Playbook.  # noqa: E501
        :rtype: list[str]
        """
        return self._propagation_labels

    @propagation_labels.setter
    def propagation_labels(self, propagation_labels):
        """Sets the propagation_labels of this Playbook.


        :param propagation_labels: The propagation_labels of this Playbook.  # noqa: E501
        :type: list[str]
        """

        self._propagation_labels = propagation_labels

    @property
    def quiet(self):
        """Gets the quiet of this Playbook.  # noqa: E501


        :return: The quiet of this Playbook.  # noqa: E501
        :rtype: bool
        """
        return self._quiet

    @quiet.setter
    def quiet(self, quiet):
        """Sets the quiet of this Playbook.


        :param quiet: The quiet of this Playbook.  # noqa: E501
        :type: bool
        """

        self._quiet = quiet

    @property
    def roles(self):
        """Gets the roles of this Playbook.  # noqa: E501

        The role assigned to this investigation  # noqa: E501

        :return: The roles of this Playbook.  # noqa: E501
        :rtype: list[str]
        """
        return self._roles

    @roles.setter
    def roles(self, roles):
        """Sets the roles of this Playbook.

        The role assigned to this investigation  # noqa: E501

        :param roles: The roles of this Playbook.  # noqa: E501
        :type: list[str]
        """

        self._roles = roles

    @property
    def script_ids(self):
        """Gets the script_ids of this Playbook.  # noqa: E501


        :return: The script_ids of this Playbook.  # noqa: E501
        :rtype: list[str]
        """
        return self._script_ids

    @script_ids.setter
    def script_ids(self, script_ids):
        """Sets the script_ids of this Playbook.


        :param script_ids: The script_ids of this Playbook.  # noqa: E501
        :type: list[str]
        """

        self._script_ids = script_ids

    @property
    def sequence_number(self):
        """Gets the sequence_number of this Playbook.  # noqa: E501


        :return: The sequence_number of this Playbook.  # noqa: E501
        :rtype: int
        """
        return self._sequence_number

    @sequence_number.setter
    def sequence_number(self, sequence_number):
        """Sets the sequence_number of this Playbook.


        :param sequence_number: The sequence_number of this Playbook.  # noqa: E501
        :type: int
        """

        self._sequence_number = sequence_number

    @property
    def should_commit(self):
        """Gets the should_commit of this Playbook.  # noqa: E501


        :return: The should_commit of this Playbook.  # noqa: E501
        :rtype: bool
        """
        return self._should_commit

    @should_commit.setter
    def should_commit(self, should_commit):
        """Sets the should_commit of this Playbook.


        :param should_commit: The should_commit of this Playbook.  # noqa: E501
        :type: bool
        """

        self._should_commit = should_commit

    @property
    def sort_values(self):
        """Gets the sort_values of this Playbook.  # noqa: E501


        :return: The sort_values of this Playbook.  # noqa: E501
        :rtype: list[str]
        """
        return self._sort_values

    @sort_values.setter
    def sort_values(self, sort_values):
        """Sets the sort_values of this Playbook.


        :param sort_values: The sort_values of this Playbook.  # noqa: E501
        :type: list[str]
        """

        self._sort_values = sort_values

    @property
    def source_playbook_id(self):
        """Gets the source_playbook_id of this Playbook.  # noqa: E501


        :return: The source_playbook_id of this Playbook.  # noqa: E501
        :rtype: str
        """
        return self._source_playbook_id

    @source_playbook_id.setter
    def source_playbook_id(self, source_playbook_id):
        """Sets the source_playbook_id of this Playbook.


        :param source_playbook_id: The source_playbook_id of this Playbook.  # noqa: E501
        :type: str
        """

        self._source_playbook_id = source_playbook_id

    @property
    def start_task_id(self):
        """Gets the start_task_id of this Playbook.  # noqa: E501


        :return: The start_task_id of this Playbook.  # noqa: E501
        :rtype: str
        """
        return self._start_task_id

    @start_task_id.setter
    def start_task_id(self, start_task_id):
        """Sets the start_task_id of this Playbook.


        :param start_task_id: The start_task_id of this Playbook.  # noqa: E501
        :type: str
        """

        self._start_task_id = start_task_id

    @property
    def system(self):
        """Gets the system of this Playbook.  # noqa: E501


        :return: The system of this Playbook.  # noqa: E501
        :rtype: bool
        """
        return self._system

    @system.setter
    def system(self, system):
        """Sets the system of this Playbook.


        :param system: The system of this Playbook.  # noqa: E501
        :type: bool
        """

        self._system = system

    @property
    def tags(self):
        """Gets the tags of this Playbook.  # noqa: E501


        :return: The tags of this Playbook.  # noqa: E501
        :rtype: list[str]
        """
        return self._tags

    @tags.setter
    def tags(self, tags):
        """Sets the tags of this Playbook.


        :param tags: The tags of this Playbook.  # noqa: E501
        :type: list[str]
        """

        self._tags = tags

    @property
    def task_ids(self):
        """Gets the task_ids of this Playbook.  # noqa: E501

        auto generated field that will contain all task ids in this playbook Needed for searching with bleve  # noqa: E501

        :return: The task_ids of this Playbook.  # noqa: E501
        :rtype: list[str]
        """
        return self._task_ids

    @task_ids.setter
    def task_ids(self, task_ids):
        """Sets the task_ids of this Playbook.

        auto generated field that will contain all task ids in this playbook Needed for searching with bleve  # noqa: E501

        :param task_ids: The task_ids of this Playbook.  # noqa: E501
        :type: list[str]
        """

        self._task_ids = task_ids

    @property
    def tasks(self):
        """Gets the tasks of this Playbook.  # noqa: E501


        :return: The tasks of this Playbook.  # noqa: E501
        :rtype: dict(str, PlaybookTask)
        """
        return self._tasks

    @tasks.setter
    def tasks(self, tasks):
        """Sets the tasks of this Playbook.


        :param tasks: The tasks of this Playbook.  # noqa: E501
        :type: dict(str, PlaybookTask)
        """

        self._tasks = tasks

    @property
    def to_server_version(self):
        """Gets the to_server_version of this Playbook.  # noqa: E501


        :return: The to_server_version of this Playbook.  # noqa: E501
        :rtype: Version
        """
        return self._to_server_version

    @to_server_version.setter
    def to_server_version(self, to_server_version):
        """Sets the to_server_version of this Playbook.


        :param to_server_version: The to_server_version of this Playbook.  # noqa: E501
        :type: Version
        """

        self._to_server_version = to_server_version

    @property
    def vc_should_ignore(self):
        """Gets the vc_should_ignore of this Playbook.  # noqa: E501


        :return: The vc_should_ignore of this Playbook.  # noqa: E501
        :rtype: bool
        """
        return self._vc_should_ignore

    @vc_should_ignore.setter
    def vc_should_ignore(self, vc_should_ignore):
        """Sets the vc_should_ignore of this Playbook.


        :param vc_should_ignore: The vc_should_ignore of this Playbook.  # noqa: E501
        :type: bool
        """

        self._vc_should_ignore = vc_should_ignore

    @property
    def version(self):
        """Gets the version of this Playbook.  # noqa: E501


        :return: The version of this Playbook.  # noqa: E501
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this Playbook.


        :param version: The version of this Playbook.  # noqa: E501
        :type: int
        """

        self._version = version

    @property
    def view(self):
        """Gets the view of this Playbook.  # noqa: E501


        :return: The view of this Playbook.  # noqa: E501
        :rtype: PlaybookView
        """
        return self._view

    @view.setter
    def view(self, view):
        """Sets the view of this Playbook.


        :param view: The view of this Playbook.  # noqa: E501
        :type: PlaybookView
        """

        self._view = view

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Playbook, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Playbook):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Demisto API

    This is the public REST API to integrate with the demisto server. HTTP request can be sent using any HTTP-client.  For an example dedicated client take a look at: https://github.com/demisto/demisto-py.  Requests must include API-key that can be generated in the Demisto web client under 'Settings' -> 'Integrations' -> 'API keys'   Optimistic Locking and Versioning\\:  When using Demisto REST API, you will need to make sure to work on the latest version of the item (incident, entry, etc.), otherwise, you will get a DB version error (which not allow you to override a newer item). In addition, you can pass 'version\\: -1' to force data override (make sure that other users data might be lost).  Assume that Alice and Bob both read the same data from Demisto server, then they both changed the data, and then both tried to write the new versions back to the server. Whose changes should be saved? Alice’s? Bob’s? To solve this, each data item in Demisto has a numeric incremental version. If Alice saved an item with version 4 and Bob trying to save the same item with version 3, Demisto will rollback Bob request and returns a DB version conflict error. Bob will need to get the latest item and work on it so Alice work will not get lost.  Example request using 'curl'\\:  ``` curl 'https://hostname:443/incidents/search' -H 'content-type: application/json' -H 'accept: application/json' -H 'Authorization: <API Key goes here>' --data-binary '{\"filter\":{\"query\":\"-status:closed -category:job\",\"period\":{\"by\":\"day\",\"fromValue\":7}}}' --compressed ```  # noqa: E501

    OpenAPI spec version: 2.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from demisto_client.demisto_api.models.argument import Argument  # noqa: F401,E501
from demisto_client.demisto_api.models.duration import Duration  # noqa: F401,E501
from demisto_client.demisto_api.models.important import Important  # noqa: F401,E501
from demisto_client.demisto_api.models.output import Output  # noqa: F401,E501
from demisto_client.demisto_api.models.script_sub_type import ScriptSubType  # noqa: F401,E501
from demisto_client.demisto_api.models.script_target import ScriptTarget  # noqa: F401,E501
from demisto_client.demisto_api.models.script_type import ScriptType  # noqa: F401,E501


class AutomationScript(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'arguments': 'list[Argument]',
        'comment': 'str',
        'commit_message': 'str',
        'context_keys': 'list[str]',
        'depends_on': 'dict(str, list[str])',
        'deprecated': 'bool',
        'docker_image': 'str',
        'enabled': 'bool',
        'has_role': 'bool',
        'hidden': 'bool',
        'id': 'str',
        'important': 'list[Important]',
        'locked': 'bool',
        'modified': 'datetime',
        'name': 'str',
        'outputs': 'list[Output]',
        'prev_name': 'str',
        'previous_roles': 'list[str]',
        'pswd': 'str',
        'raw_tags': 'list[str]',
        'roles': 'list[str]',
        'run_as': 'str',
        'run_once': 'bool',
        'script': 'str',
        'script_target': 'ScriptTarget',
        'searchable_name': 'str',
        'sensitive': 'bool',
        'should_commit': 'bool',
        'sort_values': 'list[str]',
        'subtype': 'ScriptSubType',
        'system': 'bool',
        'tags': 'list[str]',
        'timeout': 'Duration',
        'type': 'ScriptType',
        'user': 'str',
        'vc_should_ignore': 'bool',
        'version': 'int',
        'visual_script': 'str'
    }

    attribute_map = {
        'arguments': 'arguments',
        'comment': 'comment',
        'commit_message': 'commitMessage',
        'context_keys': 'contextKeys',
        'depends_on': 'dependsOn',
        'deprecated': 'deprecated',
        'docker_image': 'dockerImage',
        'enabled': 'enabled',
        'has_role': 'hasRole',
        'hidden': 'hidden',
        'id': 'id',
        'important': 'important',
        'locked': 'locked',
        'modified': 'modified',
        'name': 'name',
        'outputs': 'outputs',
        'prev_name': 'prevName',
        'previous_roles': 'previousRoles',
        'pswd': 'pswd',
        'raw_tags': 'rawTags',
        'roles': 'roles',
        'run_as': 'runAs',
        'run_once': 'runOnce',
        'script': 'script',
        'script_target': 'scriptTarget',
        'searchable_name': 'searchableName',
        'sensitive': 'sensitive',
        'should_commit': 'shouldCommit',
        'sort_values': 'sortValues',
        'subtype': 'subtype',
        'system': 'system',
        'tags': 'tags',
        'timeout': 'timeout',
        'type': 'type',
        'user': 'user',
        'vc_should_ignore': 'vcShouldIgnore',
        'version': 'version',
        'visual_script': 'visualScript'
    }

    def __init__(self, arguments=None, comment=None, commit_message=None, context_keys=None, depends_on=None, deprecated=None, docker_image=None, enabled=None, has_role=None, hidden=None, id=None, important=None, locked=None, modified=None, name=None, outputs=None, prev_name=None, previous_roles=None, pswd=None, raw_tags=None, roles=None, run_as=None, run_once=None, script=None, script_target=None, searchable_name=None, sensitive=None, should_commit=None, sort_values=None, subtype=None, system=None, tags=None, timeout=None, type=None, user=None, vc_should_ignore=None, version=None, visual_script=None):  # noqa: E501
        """AutomationScript - a model defined in Swagger"""  # noqa: E501

        self._arguments = None
        self._comment = None
        self._commit_message = None
        self._context_keys = None
        self._depends_on = None
        self._deprecated = None
        self._docker_image = None
        self._enabled = None
        self._has_role = None
        self._hidden = None
        self._id = None
        self._important = None
        self._locked = None
        self._modified = None
        self._name = None
        self._outputs = None
        self._prev_name = None
        self._previous_roles = None
        self._pswd = None
        self._raw_tags = None
        self._roles = None
        self._run_as = None
        self._run_once = None
        self._script = None
        self._script_target = None
        self._searchable_name = None
        self._sensitive = None
        self._should_commit = None
        self._sort_values = None
        self._subtype = None
        self._system = None
        self._tags = None
        self._timeout = None
        self._type = None
        self._user = None
        self._vc_should_ignore = None
        self._version = None
        self._visual_script = None
        self.discriminator = None

        if arguments is not None:
            self.arguments = arguments
        if comment is not None:
            self.comment = comment
        if commit_message is not None:
            self.commit_message = commit_message
        if context_keys is not None:
            self.context_keys = context_keys
        if depends_on is not None:
            self.depends_on = depends_on
        if deprecated is not None:
            self.deprecated = deprecated
        if docker_image is not None:
            self.docker_image = docker_image
        if enabled is not None:
            self.enabled = enabled
        if has_role is not None:
            self.has_role = has_role
        if hidden is not None:
            self.hidden = hidden
        if id is not None:
            self.id = id
        if important is not None:
            self.important = important
        if locked is not None:
            self.locked = locked
        if modified is not None:
            self.modified = modified
        if name is not None:
            self.name = name
        if outputs is not None:
            self.outputs = outputs
        if prev_name is not None:
            self.prev_name = prev_name
        if previous_roles is not None:
            self.previous_roles = previous_roles
        if pswd is not None:
            self.pswd = pswd
        if raw_tags is not None:
            self.raw_tags = raw_tags
        if roles is not None:
            self.roles = roles
        if run_as is not None:
            self.run_as = run_as
        if run_once is not None:
            self.run_once = run_once
        if script is not None:
            self.script = script
        if script_target is not None:
            self.script_target = script_target
        if searchable_name is not None:
            self.searchable_name = searchable_name
        if sensitive is not None:
            self.sensitive = sensitive
        if should_commit is not None:
            self.should_commit = should_commit
        if sort_values is not None:
            self.sort_values = sort_values
        if subtype is not None:
            self.subtype = subtype
        if system is not None:
            self.system = system
        if tags is not None:
            self.tags = tags
        if timeout is not None:
            self.timeout = timeout
        if type is not None:
            self.type = type
        if user is not None:
            self.user = user
        if vc_should_ignore is not None:
            self.vc_should_ignore = vc_should_ignore
        if version is not None:
            self.version = version
        if visual_script is not None:
            self.visual_script = visual_script

    @property
    def arguments(self):
        """Gets the arguments of this AutomationScript.  # noqa: E501


        :return: The arguments of this AutomationScript.  # noqa: E501
        :rtype: list[Argument]
        """
        return self._arguments

    @arguments.setter
    def arguments(self, arguments):
        """Sets the arguments of this AutomationScript.


        :param arguments: The arguments of this AutomationScript.  # noqa: E501
        :type: list[Argument]
        """

        self._arguments = arguments

    @property
    def comment(self):
        """Gets the comment of this AutomationScript.  # noqa: E501


        :return: The comment of this AutomationScript.  # noqa: E501
        :rtype: str
        """
        return self._comment

    @comment.setter
    def comment(self, comment):
        """Sets the comment of this AutomationScript.


        :param comment: The comment of this AutomationScript.  # noqa: E501
        :type: str
        """

        self._comment = comment

    @property
    def commit_message(self):
        """Gets the commit_message of this AutomationScript.  # noqa: E501


        :return: The commit_message of this AutomationScript.  # noqa: E501
        :rtype: str
        """
        return self._commit_message

    @commit_message.setter
    def commit_message(self, commit_message):
        """Sets the commit_message of this AutomationScript.


        :param commit_message: The commit_message of this AutomationScript.  # noqa: E501
        :type: str
        """

        self._commit_message = commit_message

    @property
    def context_keys(self):
        """Gets the context_keys of this AutomationScript.  # noqa: E501


        :return: The context_keys of this AutomationScript.  # noqa: E501
        :rtype: list[str]
        """
        return self._context_keys

    @context_keys.setter
    def context_keys(self, context_keys):
        """Sets the context_keys of this AutomationScript.


        :param context_keys: The context_keys of this AutomationScript.  # noqa: E501
        :type: list[str]
        """

        self._context_keys = context_keys

    @property
    def depends_on(self):
        """Gets the depends_on of this AutomationScript.  # noqa: E501

        This fields indicates which commands this script depends on  # noqa: E501

        :return: The depends_on of this AutomationScript.  # noqa: E501
        :rtype: dict(str, list[str])
        """
        return self._depends_on

    @depends_on.setter
    def depends_on(self, depends_on):
        """Sets the depends_on of this AutomationScript.

        This fields indicates which commands this script depends on  # noqa: E501

        :param depends_on: The depends_on of this AutomationScript.  # noqa: E501
        :type: dict(str, list[str])
        """

        self._depends_on = depends_on

    @property
    def deprecated(self):
        """Gets the deprecated of this AutomationScript.  # noqa: E501


        :return: The deprecated of this AutomationScript.  # noqa: E501
        :rtype: bool
        """
        return self._deprecated

    @deprecated.setter
    def deprecated(self, deprecated):
        """Sets the deprecated of this AutomationScript.


        :param deprecated: The deprecated of this AutomationScript.  # noqa: E501
        :type: bool
        """

        self._deprecated = deprecated

    @property
    def docker_image(self):
        """Gets the docker_image of this AutomationScript.  # noqa: E501


        :return: The docker_image of this AutomationScript.  # noqa: E501
        :rtype: str
        """
        return self._docker_image

    @docker_image.setter
    def docker_image(self, docker_image):
        """Sets the docker_image of this AutomationScript.


        :param docker_image: The docker_image of this AutomationScript.  # noqa: E501
        :type: str
        """

        self._docker_image = docker_image

    @property
    def enabled(self):
        """Gets the enabled of this AutomationScript.  # noqa: E501


        :return: The enabled of this AutomationScript.  # noqa: E501
        :rtype: bool
        """
        return self._enabled

    @enabled.setter
    def enabled(self, enabled):
        """Sets the enabled of this AutomationScript.


        :param enabled: The enabled of this AutomationScript.  # noqa: E501
        :type: bool
        """

        self._enabled = enabled

    @property
    def has_role(self):
        """Gets the has_role of this AutomationScript.  # noqa: E501

        Internal field to make queries on role faster  # noqa: E501

        :return: The has_role of this AutomationScript.  # noqa: E501
        :rtype: bool
        """
        return self._has_role

    @has_role.setter
    def has_role(self, has_role):
        """Sets the has_role of this AutomationScript.

        Internal field to make queries on role faster  # noqa: E501

        :param has_role: The has_role of this AutomationScript.  # noqa: E501
        :type: bool
        """

        self._has_role = has_role

    @property
    def hidden(self):
        """Gets the hidden of this AutomationScript.  # noqa: E501


        :return: The hidden of this AutomationScript.  # noqa: E501
        :rtype: bool
        """
        return self._hidden

    @hidden.setter
    def hidden(self, hidden):
        """Sets the hidden of this AutomationScript.


        :param hidden: The hidden of this AutomationScript.  # noqa: E501
        :type: bool
        """

        self._hidden = hidden

    @property
    def id(self):
        """Gets the id of this AutomationScript.  # noqa: E501


        :return: The id of this AutomationScript.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this AutomationScript.


        :param id: The id of this AutomationScript.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def important(self):
        """Gets the important of this AutomationScript.  # noqa: E501


        :return: The important of this AutomationScript.  # noqa: E501
        :rtype: list[Important]
        """
        return self._important

    @important.setter
    def important(self, important):
        """Sets the important of this AutomationScript.


        :param important: The important of this AutomationScript.  # noqa: E501
        :type: list[Important]
        """

        self._important = important

    @property
    def locked(self):
        """Gets the locked of this AutomationScript.  # noqa: E501


        :return: The locked of this AutomationScript.  # noqa: E501
        :rtype: bool
        """
        return self._locked

    @locked.setter
    def locked(self, locked):
        """Sets the locked of this AutomationScript.


        :param locked: The locked of this AutomationScript.  # noqa: E501
        :type: bool
        """

        self._locked = locked

    @property
    def modified(self):
        """Gets the modified of this AutomationScript.  # noqa: E501


        :return: The modified of this AutomationScript.  # noqa: E501
        :rtype: datetime
        """
        return self._modified

    @modified.setter
    def modified(self, modified):
        """Sets the modified of this AutomationScript.


        :param modified: The modified of this AutomationScript.  # noqa: E501
        :type: datetime
        """

        self._modified = modified

    @property
    def name(self):
        """Gets the name of this AutomationScript.  # noqa: E501


        :return: The name of this AutomationScript.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this AutomationScript.


        :param name: The name of this AutomationScript.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def outputs(self):
        """Gets the outputs of this AutomationScript.  # noqa: E501


        :return: The outputs of this AutomationScript.  # noqa: E501
        :rtype: list[Output]
        """
        return self._outputs

    @outputs.setter
    def outputs(self, outputs):
        """Sets the outputs of this AutomationScript.


        :param outputs: The outputs of this AutomationScript.  # noqa: E501
        :type: list[Output]
        """

        self._outputs = outputs

    @property
    def prev_name(self):
        """Gets the prev_name of this AutomationScript.  # noqa: E501


        :return: The prev_name of this AutomationScript.  # noqa: E501
        :rtype: str
        """
        return self._prev_name

    @prev_name.setter
    def prev_name(self, prev_name):
        """Sets the prev_name of this AutomationScript.


        :param prev_name: The prev_name of this AutomationScript.  # noqa: E501
        :type: str
        """

        self._prev_name = prev_name

    @property
    def previous_roles(self):
        """Gets the previous_roles of this AutomationScript.  # noqa: E501

        PreviousRoleName - do not change this field manually  # noqa: E501

        :return: The previous_roles of this AutomationScript.  # noqa: E501
        :rtype: list[str]
        """
        return self._previous_roles

    @previous_roles.setter
    def previous_roles(self, previous_roles):
        """Sets the previous_roles of this AutomationScript.

        PreviousRoleName - do not change this field manually  # noqa: E501

        :param previous_roles: The previous_roles of this AutomationScript.  # noqa: E501
        :type: list[str]
        """

        self._previous_roles = previous_roles

    @property
    def pswd(self):
        """Gets the pswd of this AutomationScript.  # noqa: E501


        :return: The pswd of this AutomationScript.  # noqa: E501
        :rtype: str
        """
        return self._pswd

    @pswd.setter
    def pswd(self, pswd):
        """Sets the pswd of this AutomationScript.


        :param pswd: The pswd of this AutomationScript.  # noqa: E501
        :type: str
        """

        self._pswd = pswd

    @property
    def raw_tags(self):
        """Gets the raw_tags of this AutomationScript.  # noqa: E501


        :return: The raw_tags of this AutomationScript.  # noqa: E501
        :rtype: list[str]
        """
        return self._raw_tags

    @raw_tags.setter
    def raw_tags(self, raw_tags):
        """Sets the raw_tags of this AutomationScript.


        :param raw_tags: The raw_tags of this AutomationScript.  # noqa: E501
        :type: list[str]
        """

        self._raw_tags = raw_tags

    @property
    def roles(self):
        """Gets the roles of this AutomationScript.  # noqa: E501

        The role assigned to this investigation  # noqa: E501

        :return: The roles of this AutomationScript.  # noqa: E501
        :rtype: list[str]
        """
        return self._roles

    @roles.setter
    def roles(self, roles):
        """Sets the roles of this AutomationScript.

        The role assigned to this investigation  # noqa: E501

        :param roles: The roles of this AutomationScript.  # noqa: E501
        :type: list[str]
        """

        self._roles = roles

    @property
    def run_as(self):
        """Gets the run_as of this AutomationScript.  # noqa: E501


        :return: The run_as of this AutomationScript.  # noqa: E501
        :rtype: str
        """
        return self._run_as

    @run_as.setter
    def run_as(self, run_as):
        """Sets the run_as of this AutomationScript.


        :param run_as: The run_as of this AutomationScript.  # noqa: E501
        :type: str
        """

        self._run_as = run_as

    @property
    def run_once(self):
        """Gets the run_once of this AutomationScript.  # noqa: E501


        :return: The run_once of this AutomationScript.  # noqa: E501
        :rtype: bool
        """
        return self._run_once

    @run_once.setter
    def run_once(self, run_once):
        """Sets the run_once of this AutomationScript.


        :param run_once: The run_once of this AutomationScript.  # noqa: E501
        :type: bool
        """

        self._run_once = run_once

    @property
    def script(self):
        """Gets the script of this AutomationScript.  # noqa: E501


        :return: The script of this AutomationScript.  # noqa: E501
        :rtype: str
        """
        return self._script

    @script.setter
    def script(self, script):
        """Sets the script of this AutomationScript.


        :param script: The script of this AutomationScript.  # noqa: E501
        :type: str
        """

        self._script = script

    @property
    def script_target(self):
        """Gets the script_target of this AutomationScript.  # noqa: E501


        :return: The script_target of this AutomationScript.  # noqa: E501
        :rtype: ScriptTarget
        """
        return self._script_target

    @script_target.setter
    def script_target(self, script_target):
        """Sets the script_target of this AutomationScript.


        :param script_target: The script_target of this AutomationScript.  # noqa: E501
        :type: ScriptTarget
        """

        self._script_target = script_target

    @property
    def searchable_name(self):
        """Gets the searchable_name of this AutomationScript.  # noqa: E501


        :return: The searchable_name of this AutomationScript.  # noqa: E501
        :rtype: str
        """
        return self._searchable_name

    @searchable_name.setter
    def searchable_name(self, searchable_name):
        """Sets the searchable_name of this AutomationScript.


        :param searchable_name: The searchable_name of this AutomationScript.  # noqa: E501
        :type: str
        """

        self._searchable_name = searchable_name

    @property
    def sensitive(self):
        """Gets the sensitive of this AutomationScript.  # noqa: E501


        :return: The sensitive of this AutomationScript.  # noqa: E501
        :rtype: bool
        """
        return self._sensitive

    @sensitive.setter
    def sensitive(self, sensitive):
        """Sets the sensitive of this AutomationScript.


        :param sensitive: The sensitive of this AutomationScript.  # noqa: E501
        :type: bool
        """

        self._sensitive = sensitive

    @property
    def should_commit(self):
        """Gets the should_commit of this AutomationScript.  # noqa: E501


        :return: The should_commit of this AutomationScript.  # noqa: E501
        :rtype: bool
        """
        return self._should_commit

    @should_commit.setter
    def should_commit(self, should_commit):
        """Sets the should_commit of this AutomationScript.


        :param should_commit: The should_commit of this AutomationScript.  # noqa: E501
        :type: bool
        """

        self._should_commit = should_commit

    @property
    def sort_values(self):
        """Gets the sort_values of this AutomationScript.  # noqa: E501


        :return: The sort_values of this AutomationScript.  # noqa: E501
        :rtype: list[str]
        """
        return self._sort_values

    @sort_values.setter
    def sort_values(self, sort_values):
        """Sets the sort_values of this AutomationScript.


        :param sort_values: The sort_values of this AutomationScript.  # noqa: E501
        :type: list[str]
        """

        self._sort_values = sort_values

    @property
    def subtype(self):
        """Gets the subtype of this AutomationScript.  # noqa: E501


        :return: The subtype of this AutomationScript.  # noqa: E501
        :rtype: ScriptSubType
        """
        return self._subtype

    @subtype.setter
    def subtype(self, subtype):
        """Sets the subtype of this AutomationScript.


        :param subtype: The subtype of this AutomationScript.  # noqa: E501
        :type: ScriptSubType
        """

        self._subtype = subtype

    @property
    def system(self):
        """Gets the system of this AutomationScript.  # noqa: E501


        :return: The system of this AutomationScript.  # noqa: E501
        :rtype: bool
        """
        return self._system

    @system.setter
    def system(self, system):
        """Sets the system of this AutomationScript.


        :param system: The system of this AutomationScript.  # noqa: E501
        :type: bool
        """

        self._system = system

    @property
    def tags(self):
        """Gets the tags of this AutomationScript.  # noqa: E501


        :return: The tags of this AutomationScript.  # noqa: E501
        :rtype: list[str]
        """
        return self._tags

    @tags.setter
    def tags(self, tags):
        """Sets the tags of this AutomationScript.


        :param tags: The tags of this AutomationScript.  # noqa: E501
        :type: list[str]
        """

        self._tags = tags

    @property
    def timeout(self):
        """Gets the timeout of this AutomationScript.  # noqa: E501


        :return: The timeout of this AutomationScript.  # noqa: E501
        :rtype: Duration
        """
        return self._timeout

    @timeout.setter
    def timeout(self, timeout):
        """Sets the timeout of this AutomationScript.


        :param timeout: The timeout of this AutomationScript.  # noqa: E501
        :type: Duration
        """

        self._timeout = timeout

    @property
    def type(self):
        """Gets the type of this AutomationScript.  # noqa: E501


        :return: The type of this AutomationScript.  # noqa: E501
        :rtype: ScriptType
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this AutomationScript.


        :param type: The type of this AutomationScript.  # noqa: E501
        :type: ScriptType
        """

        self._type = type

    @property
    def user(self):
        """Gets the user of this AutomationScript.  # noqa: E501


        :return: The user of this AutomationScript.  # noqa: E501
        :rtype: str
        """
        return self._user

    @user.setter
    def user(self, user):
        """Sets the user of this AutomationScript.


        :param user: The user of this AutomationScript.  # noqa: E501
        :type: str
        """

        self._user = user

    @property
    def vc_should_ignore(self):
        """Gets the vc_should_ignore of this AutomationScript.  # noqa: E501


        :return: The vc_should_ignore of this AutomationScript.  # noqa: E501
        :rtype: bool
        """
        return self._vc_should_ignore

    @vc_should_ignore.setter
    def vc_should_ignore(self, vc_should_ignore):
        """Sets the vc_should_ignore of this AutomationScript.


        :param vc_should_ignore: The vc_should_ignore of this AutomationScript.  # noqa: E501
        :type: bool
        """

        self._vc_should_ignore = vc_should_ignore

    @property
    def version(self):
        """Gets the version of this AutomationScript.  # noqa: E501


        :return: The version of this AutomationScript.  # noqa: E501
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this AutomationScript.


        :param version: The version of this AutomationScript.  # noqa: E501
        :type: int
        """

        self._version = version

    @property
    def visual_script(self):
        """Gets the visual_script of this AutomationScript.  # noqa: E501


        :return: The visual_script of this AutomationScript.  # noqa: E501
        :rtype: str
        """
        return self._visual_script

    @visual_script.setter
    def visual_script(self, visual_script):
        """Sets the visual_script of this AutomationScript.


        :param visual_script: The visual_script of this AutomationScript.  # noqa: E501
        :type: str
        """

        self._visual_script = visual_script

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(AutomationScript, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AutomationScript):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from __future__ import print_function
import demisto_client.demisto_api
from demisto_client.demisto_api.rest import ApiException
from pprint import pprint

api_key = 'YOUR API KEY'
base_url = 'YOUR DEMISTO URL'

# create an instance of the API class
api_instance = demisto_client.configure(base_url=base_url, api_key=api_key, debug=True)
widget = demisto_client.demisto_api.Widget()

widget.name = 'Active Incidents - Pie chart'
widget.query = '-category:job and -status:archived and -status:closed'
widget.data_type = 'incidents'
widget.widget_type = 'pie'

try:
    # Import a widget
    api_response = api_instance.import_widget(widget=widget)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling DefaultApi->import_widget: %s\n" % e)



# coding: utf-8

"""
    Demisto API

    This is the public REST API to integrate with the demisto server. HTTP request can be sent using any HTTP-client.  For an example dedicated client take a look at: https://github.com/demisto/demisto-py.  Requests must include API-key that can be generated in the Demisto web client under 'Settings' -> 'Integrations' -> 'API keys'   Optimistic Locking and Versioning\\:  When using Demisto REST API, you will need to make sure to work on the latest version of the item (incident, entry, etc.), otherwise, you will get a DB version error (which not allow you to override a newer item). In addition, you can pass 'version\\: -1' to force data override (make sure that other users data might be lost).  Assume that Alice and Bob both read the same data from Demisto server, then they both changed the data, and then both tried to write the new versions back to the server. Whose changes should be saved? Alice’s? Bob’s? To solve this, each data item in Demisto has a numeric incremental version. If Alice saved an item with version 4 and Bob trying to save the same item with version 3, Demisto will rollback Bob request and returns a DB version conflict error. Bob will need to get the latest item and work on it so Alice work will not get lost.  Example request using 'curl'\\:  ``` curl 'https://hostname:443/incidents/search' -H 'content-type: application/json' -H 'accept: application/json' -H 'Authorization: <API Key goes here>' --data-binary '{\"filter\":{\"query\":\"-status:closed -category:job\",\"period\":{\"by\":\"day\",\"fromValue\":7}}}' --compressed ```  # noqa: E501

    OpenAPI spec version: 2.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from demisto_client.demisto_api.models.reputation_calc_alg import ReputationCalcAlg  # noqa: F401,E501


class IncidentType(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'autorun': 'bool',
        'closure_script': 'str',
        'color': 'str',
        'commit_message': 'str',
        'days': 'int',
        'days_r': 'int',
        'default': 'bool',
        'disabled': 'bool',
        'hours': 'int',
        'hours_r': 'int',
        'id': 'str',
        'locked': 'bool',
        'modified': 'datetime',
        'name': 'str',
        'playbook_id': 'str',
        'pre_processing_script': 'str',
        'prev_name': 'str',
        'readonly': 'bool',
        'reputation_calc': 'ReputationCalcAlg',
        'should_commit': 'bool',
        'sla': 'int',
        'sla_reminder': 'int',
        'sort_values': 'list[str]',
        'system': 'bool',
        'vc_should_ignore': 'bool',
        'version': 'int',
        'weeks': 'int',
        'weeks_r': 'int'
    }

    attribute_map = {
        'autorun': 'autorun',
        'closure_script': 'closureScript',
        'color': 'color',
        'commit_message': 'commitMessage',
        'days': 'days',
        'days_r': 'daysR',
        'default': 'default',
        'disabled': 'disabled',
        'hours': 'hours',
        'hours_r': 'hoursR',
        'id': 'id',
        'locked': 'locked',
        'modified': 'modified',
        'name': 'name',
        'playbook_id': 'playbookId',
        'pre_processing_script': 'preProcessingScript',
        'prev_name': 'prevName',
        'readonly': 'readonly',
        'reputation_calc': 'reputationCalc',
        'should_commit': 'shouldCommit',
        'sla': 'sla',
        'sla_reminder': 'slaReminder',
        'sort_values': 'sortValues',
        'system': 'system',
        'vc_should_ignore': 'vcShouldIgnore',
        'version': 'version',
        'weeks': 'weeks',
        'weeks_r': 'weeksR'
    }

    def __init__(self, autorun=None, closure_script=None, color=None, commit_message=None, days=None, days_r=None, default=None, disabled=None, hours=None, hours_r=None, id=None, locked=None, modified=None, name=None, playbook_id=None, pre_processing_script=None, prev_name=None, readonly=None, reputation_calc=None, should_commit=None, sla=None, sla_reminder=None, sort_values=None, system=None, vc_should_ignore=None, version=None, weeks=None, weeks_r=None):  # noqa: E501
        """IncidentType - a model defined in Swagger"""  # noqa: E501

        self._autorun = None
        self._closure_script = None
        self._color = None
        self._commit_message = None
        self._days = None
        self._days_r = None
        self._default = None
        self._disabled = None
        self._hours = None
        self._hours_r = None
        self._id = None
        self._locked = None
        self._modified = None
        self._name = None
        self._playbook_id = None
        self._pre_processing_script = None
        self._prev_name = None
        self._readonly = None
        self._reputation_calc = None
        self._should_commit = None
        self._sla = None
        self._sla_reminder = None
        self._sort_values = None
        self._system = None
        self._vc_should_ignore = None
        self._version = None
        self._weeks = None
        self._weeks_r = None
        self.discriminator = None

        if autorun is not None:
            self.autorun = autorun
        if closure_script is not None:
            self.closure_script = closure_script
        if color is not None:
            self.color = color
        if commit_message is not None:
            self.commit_message = commit_message
        if days is not None:
            self.days = days
        if days_r is not None:
            self.days_r = days_r
        if default is not None:
            self.default = default
        if disabled is not None:
            self.disabled = disabled
        if hours is not None:
            self.hours = hours
        if hours_r is not None:
            self.hours_r = hours_r
        if id is not None:
            self.id = id
        if locked is not None:
            self.locked = locked
        if modified is not None:
            self.modified = modified
        if name is not None:
            self.name = name
        if playbook_id is not None:
            self.playbook_id = playbook_id
        if pre_processing_script is not None:
            self.pre_processing_script = pre_processing_script
        if prev_name is not None:
            self.prev_name = prev_name
        if readonly is not None:
            self.readonly = readonly
        if reputation_calc is not None:
            self.reputation_calc = reputation_calc
        if should_commit is not None:
            self.should_commit = should_commit
        if sla is not None:
            self.sla = sla
        if sla_reminder is not None:
            self.sla_reminder = sla_reminder
        if sort_values is not None:
            self.sort_values = sort_values
        if system is not None:
            self.system = system
        if vc_should_ignore is not None:
            self.vc_should_ignore = vc_should_ignore
        if version is not None:
            self.version = version
        if weeks is not None:
            self.weeks = weeks
        if weeks_r is not None:
            self.weeks_r = weeks_r

    @property
    def autorun(self):
        """Gets the autorun of this IncidentType.  # noqa: E501


        :return: The autorun of this IncidentType.  # noqa: E501
        :rtype: bool
        """
        return self._autorun

    @autorun.setter
    def autorun(self, autorun):
        """Sets the autorun of this IncidentType.


        :param autorun: The autorun of this IncidentType.  # noqa: E501
        :type: bool
        """

        self._autorun = autorun

    @property
    def closure_script(self):
        """Gets the closure_script of this IncidentType.  # noqa: E501


        :return: The closure_script of this IncidentType.  # noqa: E501
        :rtype: str
        """
        return self._closure_script

    @closure_script.setter
    def closure_script(self, closure_script):
        """Sets the closure_script of this IncidentType.


        :param closure_script: The closure_script of this IncidentType.  # noqa: E501
        :type: str
        """

        self._closure_script = closure_script

    @property
    def color(self):
        """Gets the color of this IncidentType.  # noqa: E501


        :return: The color of this IncidentType.  # noqa: E501
        :rtype: str
        """
        return self._color

    @color.setter
    def color(self, color):
        """Sets the color of this IncidentType.


        :param color: The color of this IncidentType.  # noqa: E501
        :type: str
        """

        self._color = color

    @property
    def commit_message(self):
        """Gets the commit_message of this IncidentType.  # noqa: E501


        :return: The commit_message of this IncidentType.  # noqa: E501
        :rtype: str
        """
        return self._commit_message

    @commit_message.setter
    def commit_message(self, commit_message):
        """Sets the commit_message of this IncidentType.


        :param commit_message: The commit_message of this IncidentType.  # noqa: E501
        :type: str
        """

        self._commit_message = commit_message

    @property
    def days(self):
        """Gets the days of this IncidentType.  # noqa: E501


        :return: The days of this IncidentType.  # noqa: E501
        :rtype: int
        """
        return self._days

    @days.setter
    def days(self, days):
        """Sets the days of this IncidentType.


        :param days: The days of this IncidentType.  # noqa: E501
        :type: int
        """

        self._days = days

    @property
    def days_r(self):
        """Gets the days_r of this IncidentType.  # noqa: E501


        :return: The days_r of this IncidentType.  # noqa: E501
        :rtype: int
        """
        return self._days_r

    @days_r.setter
    def days_r(self, days_r):
        """Sets the days_r of this IncidentType.


        :param days_r: The days_r of this IncidentType.  # noqa: E501
        :type: int
        """

        self._days_r = days_r

    @property
    def default(self):
        """Gets the default of this IncidentType.  # noqa: E501


        :return: The default of this IncidentType.  # noqa: E501
        :rtype: bool
        """
        return self._default

    @default.setter
    def default(self, default):
        """Sets the default of this IncidentType.


        :param default: The default of this IncidentType.  # noqa: E501
        :type: bool
        """

        self._default = default

    @property
    def disabled(self):
        """Gets the disabled of this IncidentType.  # noqa: E501


        :return: The disabled of this IncidentType.  # noqa: E501
        :rtype: bool
        """
        return self._disabled

    @disabled.setter
    def disabled(self, disabled):
        """Sets the disabled of this IncidentType.


        :param disabled: The disabled of this IncidentType.  # noqa: E501
        :type: bool
        """

        self._disabled = disabled

    @property
    def hours(self):
        """Gets the hours of this IncidentType.  # noqa: E501


        :return: The hours of this IncidentType.  # noqa: E501
        :rtype: int
        """
        return self._hours

    @hours.setter
    def hours(self, hours):
        """Sets the hours of this IncidentType.


        :param hours: The hours of this IncidentType.  # noqa: E501
        :type: int
        """

        self._hours = hours

    @property
    def hours_r(self):
        """Gets the hours_r of this IncidentType.  # noqa: E501


        :return: The hours_r of this IncidentType.  # noqa: E501
        :rtype: int
        """
        return self._hours_r

    @hours_r.setter
    def hours_r(self, hours_r):
        """Sets the hours_r of this IncidentType.


        :param hours_r: The hours_r of this IncidentType.  # noqa: E501
        :type: int
        """

        self._hours_r = hours_r

    @property
    def id(self):
        """Gets the id of this IncidentType.  # noqa: E501


        :return: The id of this IncidentType.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this IncidentType.


        :param id: The id of this IncidentType.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def locked(self):
        """Gets the locked of this IncidentType.  # noqa: E501


        :return: The locked of this IncidentType.  # noqa: E501
        :rtype: bool
        """
        return self._locked

    @locked.setter
    def locked(self, locked):
        """Sets the locked of this IncidentType.


        :param locked: The locked of this IncidentType.  # noqa: E501
        :type: bool
        """

        self._locked = locked

    @property
    def modified(self):
        """Gets the modified of this IncidentType.  # noqa: E501


        :return: The modified of this IncidentType.  # noqa: E501
        :rtype: datetime
        """
        return self._modified

    @modified.setter
    def modified(self, modified):
        """Sets the modified of this IncidentType.


        :param modified: The modified of this IncidentType.  # noqa: E501
        :type: datetime
        """

        self._modified = modified

    @property
    def name(self):
        """Gets the name of this IncidentType.  # noqa: E501


        :return: The name of this IncidentType.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this IncidentType.


        :param name: The name of this IncidentType.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def playbook_id(self):
        """Gets the playbook_id of this IncidentType.  # noqa: E501


        :return: The playbook_id of this IncidentType.  # noqa: E501
        :rtype: str
        """
        return self._playbook_id

    @playbook_id.setter
    def playbook_id(self, playbook_id):
        """Sets the playbook_id of this IncidentType.


        :param playbook_id: The playbook_id of this IncidentType.  # noqa: E501
        :type: str
        """

        self._playbook_id = playbook_id

    @property
    def pre_processing_script(self):
        """Gets the pre_processing_script of this IncidentType.  # noqa: E501


        :return: The pre_processing_script of this IncidentType.  # noqa: E501
        :rtype: str
        """
        return self._pre_processing_script

    @pre_processing_script.setter
    def pre_processing_script(self, pre_processing_script):
        """Sets the pre_processing_script of this IncidentType.


        :param pre_processing_script: The pre_processing_script of this IncidentType.  # noqa: E501
        :type: str
        """

        self._pre_processing_script = pre_processing_script

    @property
    def prev_name(self):
        """Gets the prev_name of this IncidentType.  # noqa: E501


        :return: The prev_name of this IncidentType.  # noqa: E501
        :rtype: str
        """
        return self._prev_name

    @prev_name.setter
    def prev_name(self, prev_name):
        """Sets the prev_name of this IncidentType.


        :param prev_name: The prev_name of this IncidentType.  # noqa: E501
        :type: str
        """

        self._prev_name = prev_name

    @property
    def readonly(self):
        """Gets the readonly of this IncidentType.  # noqa: E501


        :return: The readonly of this IncidentType.  # noqa: E501
        :rtype: bool
        """
        return self._readonly

    @readonly.setter
    def readonly(self, readonly):
        """Sets the readonly of this IncidentType.


        :param readonly: The readonly of this IncidentType.  # noqa: E501
        :type: bool
        """

        self._readonly = readonly

    @property
    def reputation_calc(self):
        """Gets the reputation_calc of this IncidentType.  # noqa: E501


        :return: The reputation_calc of this IncidentType.  # noqa: E501
        :rtype: ReputationCalcAlg
        """
        return self._reputation_calc

    @reputation_calc.setter
    def reputation_calc(self, reputation_calc):
        """Sets the reputation_calc of this IncidentType.


        :param reputation_calc: The reputation_calc of this IncidentType.  # noqa: E501
        :type: ReputationCalcAlg
        """

        self._reputation_calc = reputation_calc

    @property
    def should_commit(self):
        """Gets the should_commit of this IncidentType.  # noqa: E501


        :return: The should_commit of this IncidentType.  # noqa: E501
        :rtype: bool
        """
        return self._should_commit

    @should_commit.setter
    def should_commit(self, should_commit):
        """Sets the should_commit of this IncidentType.


        :param should_commit: The should_commit of this IncidentType.  # noqa: E501
        :type: bool
        """

        self._should_commit = should_commit

    @property
    def sla(self):
        """Gets the sla of this IncidentType.  # noqa: E501


        :return: The sla of this IncidentType.  # noqa: E501
        :rtype: int
        """
        return self._sla

    @sla.setter
    def sla(self, sla):
        """Sets the sla of this IncidentType.


        :param sla: The sla of this IncidentType.  # noqa: E501
        :type: int
        """

        self._sla = sla

    @property
    def sla_reminder(self):
        """Gets the sla_reminder of this IncidentType.  # noqa: E501


        :return: The sla_reminder of this IncidentType.  # noqa: E501
        :rtype: int
        """
        return self._sla_reminder

    @sla_reminder.setter
    def sla_reminder(self, sla_reminder):
        """Sets the sla_reminder of this IncidentType.


        :param sla_reminder: The sla_reminder of this IncidentType.  # noqa: E501
        :type: int
        """

        self._sla_reminder = sla_reminder

    @property
    def sort_values(self):
        """Gets the sort_values of this IncidentType.  # noqa: E501


        :return: The sort_values of this IncidentType.  # noqa: E501
        :rtype: list[str]
        """
        return self._sort_values

    @sort_values.setter
    def sort_values(self, sort_values):
        """Sets the sort_values of this IncidentType.


        :param sort_values: The sort_values of this IncidentType.  # noqa: E501
        :type: list[str]
        """

        self._sort_values = sort_values

    @property
    def system(self):
        """Gets the system of this IncidentType.  # noqa: E501


        :return: The system of this IncidentType.  # noqa: E501
        :rtype: bool
        """
        return self._system

    @system.setter
    def system(self, system):
        """Sets the system of this IncidentType.


        :param system: The system of this IncidentType.  # noqa: E501
        :type: bool
        """

        self._system = system

    @property
    def vc_should_ignore(self):
        """Gets the vc_should_ignore of this IncidentType.  # noqa: E501


        :return: The vc_should_ignore of this IncidentType.  # noqa: E501
        :rtype: bool
        """
        return self._vc_should_ignore

    @vc_should_ignore.setter
    def vc_should_ignore(self, vc_should_ignore):
        """Sets the vc_should_ignore of this IncidentType.


        :param vc_should_ignore: The vc_should_ignore of this IncidentType.  # noqa: E501
        :type: bool
        """

        self._vc_should_ignore = vc_should_ignore

    @property
    def version(self):
        """Gets the version of this IncidentType.  # noqa: E501


        :return: The version of this IncidentType.  # noqa: E501
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this IncidentType.


        :param version: The version of this IncidentType.  # noqa: E501
        :type: int
        """

        self._version = version

    @property
    def weeks(self):
        """Gets the weeks of this IncidentType.  # noqa: E501


        :return: The weeks of this IncidentType.  # noqa: E501
        :rtype: int
        """
        return self._weeks

    @weeks.setter
    def weeks(self, weeks):
        """Sets the weeks of this IncidentType.


        :param weeks: The weeks of this IncidentType.  # noqa: E501
        :type: int
        """

        self._weeks = weeks

    @property
    def weeks_r(self):
        """Gets the weeks_r of this IncidentType.  # noqa: E501


        :return: The weeks_r of this IncidentType.  # noqa: E501
        :rtype: int
        """
        return self._weeks_r

    @weeks_r.setter
    def weeks_r(self, weeks_r):
        """Sets the weeks_r of this IncidentType.


        :param weeks_r: The weeks_r of this IncidentType.  # noqa: E501
        :type: int
        """

        self._weeks_r = weeks_r

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(IncidentType, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, IncidentType):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Demisto API

    This is the public REST API to integrate with the demisto server. HTTP request can be sent using any HTTP-client.  For an example dedicated client take a look at: https://github.com/demisto/demisto-py.  Requests must include API-key that can be generated in the Demisto web client under 'Settings' -> 'Integrations' -> 'API keys'   Optimistic Locking and Versioning\\:  When using Demisto REST API, you will need to make sure to work on the latest version of the item (incident, entry, etc.), otherwise, you will get a DB version error (which not allow you to override a newer item). In addition, you can pass 'version\\: -1' to force data override (make sure that other users data might be lost).  Assume that Alice and Bob both read the same data from Demisto server, then they both changed the data, and then both tried to write the new versions back to the server. Whose changes should be saved? Alice’s? Bob’s? To solve this, each data item in Demisto has a numeric incremental version. If Alice saved an item with version 4 and Bob trying to save the same item with version 3, Demisto will rollback Bob request and returns a DB version conflict error. Bob will need to get the latest item and work on it so Alice work will not get lost.  Example request using 'curl'\\:  ``` curl 'https://hostname:443/incidents/search' -H 'content-type: application/json' -H 'accept: application/json' -H 'Authorization: <API Key goes here>' --data-binary '{\"filter\":{\"query\":\"-status:closed -category:job\",\"period\":{\"by\":\"day\",\"fromValue\":7}}}' --compressed ```  # noqa: E501

    OpenAPI spec version: 2.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from demisto_client.demisto_api.models.date_range import DateRange  # noqa: F401,E501
from demisto_client.demisto_api.models.order import Order  # noqa: F401,E501


class Widget(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'category': 'str',
        'commit_message': 'str',
        'data_type': 'str',
        'date_range': 'DateRange',
        'description': 'str',
        'id': 'str',
        'is_predefined': 'bool',
        'locked': 'bool',
        'modified': 'datetime',
        'name': 'str',
        'params': 'dict(str, object)',
        'prev_name': 'str',
        'query': 'str',
        'should_commit': 'bool',
        'size': 'int',
        'sort': 'list[Order]',
        'sort_values': 'list[str]',
        'vc_should_ignore': 'bool',
        'version': 'int',
        'widget_type': 'str'
    }

    attribute_map = {
        'category': 'category',
        'commit_message': 'commitMessage',
        'data_type': 'dataType',
        'date_range': 'dateRange',
        'description': 'description',
        'id': 'id',
        'is_predefined': 'isPredefined',
        'locked': 'locked',
        'modified': 'modified',
        'name': 'name',
        'params': 'params',
        'prev_name': 'prevName',
        'query': 'query',
        'should_commit': 'shouldCommit',
        'size': 'size',
        'sort': 'sort',
        'sort_values': 'sortValues',
        'vc_should_ignore': 'vcShouldIgnore',
        'version': 'version',
        'widget_type': 'widgetType'
    }

    def __init__(self, category=None, commit_message=None, data_type=None, date_range=None, description=None, id=None, is_predefined=None, locked=None, modified=None, name=None, params=None, prev_name=None, query=None, should_commit=None, size=None, sort=None, sort_values=None, vc_should_ignore=None, version=None, widget_type=None):  # noqa: E501
        """Widget - a model defined in Swagger"""  # noqa: E501

        self._category = None
        self._commit_message = None
        self._data_type = None
        self._date_range = None
        self._description = None
        self._id = None
        self._is_predefined = None
        self._locked = None
        self._modified = None
        self._name = None
        self._params = None
        self._prev_name = None
        self._query = None
        self._should_commit = None
        self._size = None
        self._sort = None
        self._sort_values = None
        self._vc_should_ignore = None
        self._version = None
        self._widget_type = None
        self.discriminator = None

        if category is not None:
            self.category = category
        if commit_message is not None:
            self.commit_message = commit_message
        if data_type is not None:
            self.data_type = data_type
        if date_range is not None:
            self.date_range = date_range
        if description is not None:
            self.description = description
        if id is not None:
            self.id = id
        if is_predefined is not None:
            self.is_predefined = is_predefined
        if locked is not None:
            self.locked = locked
        if modified is not None:
            self.modified = modified
        self.name = name
        if params is not None:
            self.params = params
        if prev_name is not None:
            self.prev_name = prev_name
        if query is not None:
            self.query = query
        if should_commit is not None:
            self.should_commit = should_commit
        if size is not None:
            self.size = size
        if sort is not None:
            self.sort = sort
        if sort_values is not None:
            self.sort_values = sort_values
        if vc_should_ignore is not None:
            self.vc_should_ignore = vc_should_ignore
        if version is not None:
            self.version = version
        self.widget_type = widget_type

    @property
    def category(self):
        """Gets the category of this Widget.  # noqa: E501

        Category the widget is related to. Used to display in widget library under category or dataType if empty.  # noqa: E501

        :return: The category of this Widget.  # noqa: E501
        :rtype: str
        """
        return self._category

    @category.setter
    def category(self, category):
        """Sets the category of this Widget.

        Category the widget is related to. Used to display in widget library under category or dataType if empty.  # noqa: E501

        :param category: The category of this Widget.  # noqa: E501
        :type: str
        """

        self._category = category

    @property
    def commit_message(self):
        """Gets the commit_message of this Widget.  # noqa: E501


        :return: The commit_message of this Widget.  # noqa: E501
        :rtype: str
        """
        return self._commit_message

    @commit_message.setter
    def commit_message(self, commit_message):
        """Sets the commit_message of this Widget.


        :param commit_message: The commit_message of this Widget.  # noqa: E501
        :type: str
        """

        self._commit_message = commit_message

    @property
    def data_type(self):
        """Gets the data_type of this Widget.  # noqa: E501

        Data type of the widget. Describes what data does the widget query. supporting data types \"incidents\",\"messages\",\"system\",\"entries\",\"tasks\", \"audit\".  # noqa: E501

        :return: The data_type of this Widget.  # noqa: E501
        :rtype: str
        """
        return self._data_type

    @data_type.setter
    def data_type(self, data_type):
        """Sets the data_type of this Widget.

        Data type of the widget. Describes what data does the widget query. supporting data types \"incidents\",\"messages\",\"system\",\"entries\",\"tasks\", \"audit\".  # noqa: E501

        :param data_type: The data_type of this Widget.  # noqa: E501
        :type: str
        """

        self._data_type = data_type

    @property
    def date_range(self):
        """Gets the date_range of this Widget.  # noqa: E501


        :return: The date_range of this Widget.  # noqa: E501
        :rtype: DateRange
        """
        return self._date_range

    @date_range.setter
    def date_range(self, date_range):
        """Sets the date_range of this Widget.


        :param date_range: The date_range of this Widget.  # noqa: E501
        :type: DateRange
        """

        self._date_range = date_range

    @property
    def description(self):
        """Gets the description of this Widget.  # noqa: E501

        The description of the widget's usage and data representation.  # noqa: E501

        :return: The description of this Widget.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this Widget.

        The description of the widget's usage and data representation.  # noqa: E501

        :param description: The description of this Widget.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def id(self):
        """Gets the id of this Widget.  # noqa: E501


        :return: The id of this Widget.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Widget.


        :param id: The id of this Widget.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def is_predefined(self):
        """Gets the is_predefined of this Widget.  # noqa: E501

        Is the widget a system widget.  # noqa: E501

        :return: The is_predefined of this Widget.  # noqa: E501
        :rtype: bool
        """
        return self._is_predefined

    @is_predefined.setter
    def is_predefined(self, is_predefined):
        """Sets the is_predefined of this Widget.

        Is the widget a system widget.  # noqa: E501

        :param is_predefined: The is_predefined of this Widget.  # noqa: E501
        :type: bool
        """

        self._is_predefined = is_predefined

    @property
    def locked(self):
        """Gets the locked of this Widget.  # noqa: E501

        Is the widget locked for editing.  # noqa: E501

        :return: The locked of this Widget.  # noqa: E501
        :rtype: bool
        """
        return self._locked

    @locked.setter
    def locked(self, locked):
        """Sets the locked of this Widget.

        Is the widget locked for editing.  # noqa: E501

        :param locked: The locked of this Widget.  # noqa: E501
        :type: bool
        """

        self._locked = locked

    @property
    def modified(self):
        """Gets the modified of this Widget.  # noqa: E501


        :return: The modified of this Widget.  # noqa: E501
        :rtype: datetime
        """
        return self._modified

    @modified.setter
    def modified(self, modified):
        """Sets the modified of this Widget.


        :param modified: The modified of this Widget.  # noqa: E501
        :type: datetime
        """

        self._modified = modified

    @property
    def name(self):
        """Gets the name of this Widget.  # noqa: E501

        Default name of the widget.  # noqa: E501

        :return: The name of this Widget.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Widget.

        Default name of the widget.  # noqa: E501

        :param name: The name of this Widget.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def params(self):
        """Gets the params of this Widget.  # noqa: E501

        Additional parameters for this widget, depends on widget type and data.  # noqa: E501

        :return: The params of this Widget.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._params

    @params.setter
    def params(self, params):
        """Sets the params of this Widget.

        Additional parameters for this widget, depends on widget type and data.  # noqa: E501

        :param params: The params of this Widget.  # noqa: E501
        :type: dict(str, object)
        """

        self._params = params

    @property
    def prev_name(self):
        """Gets the prev_name of this Widget.  # noqa: E501

        The previous name of the widget.  # noqa: E501

        :return: The prev_name of this Widget.  # noqa: E501
        :rtype: str
        """
        return self._prev_name

    @prev_name.setter
    def prev_name(self, prev_name):
        """Sets the prev_name of this Widget.

        The previous name of the widget.  # noqa: E501

        :param prev_name: The prev_name of this Widget.  # noqa: E501
        :type: str
        """

        self._prev_name = prev_name

    @property
    def query(self):
        """Gets the query of this Widget.  # noqa: E501

        Query to search on the dataType.  # noqa: E501

        :return: The query of this Widget.  # noqa: E501
        :rtype: str
        """
        return self._query

    @query.setter
    def query(self, query):
        """Sets the query of this Widget.

        Query to search on the dataType.  # noqa: E501

        :param query: The query of this Widget.  # noqa: E501
        :type: str
        """

        self._query = query

    @property
    def should_commit(self):
        """Gets the should_commit of this Widget.  # noqa: E501


        :return: The should_commit of this Widget.  # noqa: E501
        :rtype: bool
        """
        return self._should_commit

    @should_commit.setter
    def should_commit(self, should_commit):
        """Sets the should_commit of this Widget.


        :param should_commit: The should_commit of this Widget.  # noqa: E501
        :type: bool
        """

        self._should_commit = should_commit

    @property
    def size(self):
        """Gets the size of this Widget.  # noqa: E501

        Maximum size for this widget data returned.  # noqa: E501

        :return: The size of this Widget.  # noqa: E501
        :rtype: int
        """
        return self._size

    @size.setter
    def size(self, size):
        """Sets the size of this Widget.

        Maximum size for this widget data returned.  # noqa: E501

        :param size: The size of this Widget.  # noqa: E501
        :type: int
        """

        self._size = size

    @property
    def sort(self):
        """Gets the sort of this Widget.  # noqa: E501

        Sorting array to sort the data received by the given Order parameters.  # noqa: E501

        :return: The sort of this Widget.  # noqa: E501
        :rtype: list[Order]
        """
        return self._sort

    @sort.setter
    def sort(self, sort):
        """Sets the sort of this Widget.

        Sorting array to sort the data received by the given Order parameters.  # noqa: E501

        :param sort: The sort of this Widget.  # noqa: E501
        :type: list[Order]
        """

        self._sort = sort

    @property
    def sort_values(self):
        """Gets the sort_values of this Widget.  # noqa: E501


        :return: The sort_values of this Widget.  # noqa: E501
        :rtype: list[str]
        """
        return self._sort_values

    @sort_values.setter
    def sort_values(self, sort_values):
        """Sets the sort_values of this Widget.


        :param sort_values: The sort_values of this Widget.  # noqa: E501
        :type: list[str]
        """

        self._sort_values = sort_values

    @property
    def vc_should_ignore(self):
        """Gets the vc_should_ignore of this Widget.  # noqa: E501


        :return: The vc_should_ignore of this Widget.  # noqa: E501
        :rtype: bool
        """
        return self._vc_should_ignore

    @vc_should_ignore.setter
    def vc_should_ignore(self, vc_should_ignore):
        """Sets the vc_should_ignore of this Widget.


        :param vc_should_ignore: The vc_should_ignore of this Widget.  # noqa: E501
        :type: bool
        """

        self._vc_should_ignore = vc_should_ignore

    @property
    def version(self):
        """Gets the version of this Widget.  # noqa: E501


        :return: The version of this Widget.  # noqa: E501
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this Widget.


        :param version: The version of this Widget.  # noqa: E501
        :type: int
        """

        self._version = version

    @property
    def widget_type(self):
        """Gets the widget_type of this Widget.  # noqa: E501

        Widget type describes how does the widget should recieve the data, and display it. Supporting types: \"bar\", \"column\", \"pie\", \"list\", \"number\", \"trend\", \"text\", \"duration\", \"image\", \"line\", and \"table\".  # noqa: E501

        :return: The widget_type of this Widget.  # noqa: E501
        :rtype: str
        """
        return self._widget_type

    @widget_type.setter
    def widget_type(self, widget_type):
        """Sets the widget_type of this Widget.

        Widget type describes how does the widget should recieve the data, and display it. Supporting types: \"bar\", \"column\", \"pie\", \"list\", \"number\", \"trend\", \"text\", \"duration\", \"image\", \"line\", and \"table\".  # noqa: E501

        :param widget_type: The widget_type of this Widget.  # noqa: E501
        :type: str
        """
        if widget_type is None:
            raise ValueError("Invalid value for `widget_type`, must not be `None`")  # noqa: E501

        self._widget_type = widget_type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Widget, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Widget):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Demisto API
"""


from setuptools import setup, find_packages  # noqa: H301

NAME = "demisto-py"

# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools

with open('requirements.txt') as f:
    REQUIRES = f.read().splitlines()

with open('README.md', 'r') as f:
    readme = f.read()
    

setup(
    use_scm_version={
        'local_scheme': lambda a: ""
    },
    setup_requires=['setuptools_scm'],
    name=NAME,
    description="A Python library for the Demisto API",
    author_email="",
    url="https://github.com/demisto/demisto-py",
    keywords=["Swagger", "Demisto API"],
    install_requires=REQUIRES,
    packages=find_packages(),
    python_requires='>=3.8',
    include_package_data=True,
    long_description=readme,
    long_description_content_type='text/markdown',
    license='Apache Software License',
    classifiers=[
        'Intended Audience :: Developers',
        'Natural Language :: English',
        'License :: OSI Approved :: Apache Software License',
        'Programming Language :: Python',    
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: 3.10',
        'Programming Language :: Python :: Implementation :: CPython'
    ],
)



# coding: utf-8

"""
    Demisto API

    This is the public REST API to integrate with the demisto server. HTTP request can be sent using any HTTP-client.  For an example dedicated client take a look at: https://github.com/demisto/demisto-py.  Requests must include API-key that can be generated in the Demisto web client under 'Settings' -> 'Integrations' -> 'API keys'   Optimistic Locking and Versioning\\:  When using Demisto REST API, you will need to make sure to work on the latest version of the item (incident, entry, etc.), otherwise, you will get a DB version error (which not allow you to override a newer item). In addition, you can pass 'version\\: -1' to force data override (make sure that other users data might be lost).  Assume that Alice and Bob both read the same data from Demisto server, then they both changed the data, and then both tried to write the new versions back to the server. Whose changes should be saved? Alice’s? Bob’s? To solve this, each data item in Demisto has a numeric incremental version. If Alice saved an item with version 4 and Bob trying to save the same item with version 3, Demisto will rollback Bob request and returns a DB version conflict error. Bob will need to get the latest item and work on it so Alice work will not get lost.  Example request using 'curl'\\:  ``` curl 'https://hostname:443/incidents/search' -H 'content-type: application/json' -H 'accept: application/json' -H 'Authorization: <API Key goes here>' --data-binary '{\"filter\":{\"query\":\"-status:closed -category:job\",\"period\":{\"by\":\"day\",\"fromValue\":7}}}' --compressed ```  # noqa: E501

    OpenAPI spec version: 2.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from demisto_client.demisto_api.models.duration import Duration  # noqa: F401,E501
from demisto_client.demisto_api.models.investigation_status import InvestigationStatus  # noqa: F401,E501
from demisto_client.demisto_api.models.investigation_type import InvestigationType  # noqa: F401,E501
from demisto_client.demisto_api.models.order import Order  # noqa: F401,E501
from demisto_client.demisto_api.models.period import Period  # noqa: F401,E501


class InvestigationFilter(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'cache': 'dict(str, list[str])',
        'and_op': 'bool',
        'category': 'list[str]',
        'from_close_date': 'datetime',
        'from_date': 'datetime',
        'from_date_license': 'datetime',
        'id': 'list[str]',
        'ids_only': 'bool',
        'include_child_inv': 'bool',
        'name': 'list[str]',
        'not_category': 'list[str]',
        'not_i_ds': 'list[str]',
        'page': 'int',
        'period': 'Period',
        'reason': 'list[str]',
        'search_after': 'list[str]',
        'search_before': 'list[str]',
        'size': 'int',
        'sort': 'list[Order]',
        'status': 'list[InvestigationStatus]',
        'time_frame': 'Duration',
        'to_close_date': 'datetime',
        'to_date': 'datetime',
        'type': 'list[InvestigationType]',
        'user': 'list[str]'
    }

    attribute_map = {
        'cache': 'Cache',
        'and_op': 'andOp',
        'category': 'category',
        'from_close_date': 'fromCloseDate',
        'from_date': 'fromDate',
        'from_date_license': 'fromDateLicense',
        'id': 'id',
        'ids_only': 'idsOnly',
        'include_child_inv': 'includeChildInv',
        'name': 'name',
        'not_category': 'notCategory',
        'not_i_ds': 'notIDs',
        'page': 'page',
        'period': 'period',
        'reason': 'reason',
        'search_after': 'searchAfter',
        'search_before': 'searchBefore',
        'size': 'size',
        'sort': 'sort',
        'status': 'status',
        'time_frame': 'timeFrame',
        'to_close_date': 'toCloseDate',
        'to_date': 'toDate',
        'type': 'type',
        'user': 'user'
    }

    def __init__(self, cache=None, and_op=None, category=None, from_close_date=None, from_date=None, from_date_license=None, id=None, ids_only=None, include_child_inv=None, name=None, not_category=None, not_i_ds=None, page=None, period=None, reason=None, search_after=None, search_before=None, size=None, sort=None, status=None, time_frame=None, to_close_date=None, to_date=None, type=None, user=None):  # noqa: E501
        """InvestigationFilter - a model defined in Swagger"""  # noqa: E501

        self._cache = None
        self._and_op = None
        self._category = None
        self._from_close_date = None
        self._from_date = None
        self._from_date_license = None
        self._id = None
        self._ids_only = None
        self._include_child_inv = None
        self._name = None
        self._not_category = None
        self._not_i_ds = None
        self._page = None
        self._period = None
        self._reason = None
        self._search_after = None
        self._search_before = None
        self._size = None
        self._sort = None
        self._status = None
        self._time_frame = None
        self._to_close_date = None
        self._to_date = None
        self._type = None
        self._user = None
        self.discriminator = None

        if cache is not None:
            self.cache = cache
        if and_op is not None:
            self.and_op = and_op
        if category is not None:
            self.category = category
        if from_close_date is not None:
            self.from_close_date = from_close_date
        if from_date is not None:
            self.from_date = from_date
        if from_date_license is not None:
            self.from_date_license = from_date_license
        if id is not None:
            self.id = id
        if ids_only is not None:
            self.ids_only = ids_only
        if include_child_inv is not None:
            self.include_child_inv = include_child_inv
        if name is not None:
            self.name = name
        if not_category is not None:
            self.not_category = not_category
        if not_i_ds is not None:
            self.not_i_ds = not_i_ds
        if page is not None:
            self.page = page
        if period is not None:
            self.period = period
        if reason is not None:
            self.reason = reason
        if search_after is not None:
            self.search_after = search_after
        if search_before is not None:
            self.search_before = search_before
        if size is not None:
            self.size = size
        if sort is not None:
            self.sort = sort
        if status is not None:
            self.status = status
        if time_frame is not None:
            self.time_frame = time_frame
        if to_close_date is not None:
            self.to_close_date = to_close_date
        if to_date is not None:
            self.to_date = to_date
        if type is not None:
            self.type = type
        if user is not None:
            self.user = user

    @property
    def cache(self):
        """Gets the cache of this InvestigationFilter.  # noqa: E501

        Cache of join functions  # noqa: E501

        :return: The cache of this InvestigationFilter.  # noqa: E501
        :rtype: dict(str, list[str])
        """
        return self._cache

    @cache.setter
    def cache(self, cache):
        """Sets the cache of this InvestigationFilter.

        Cache of join functions  # noqa: E501

        :param cache: The cache of this InvestigationFilter.  # noqa: E501
        :type: dict(str, list[str])
        """

        self._cache = cache

    @property
    def and_op(self):
        """Gets the and_op of this InvestigationFilter.  # noqa: E501


        :return: The and_op of this InvestigationFilter.  # noqa: E501
        :rtype: bool
        """
        return self._and_op

    @and_op.setter
    def and_op(self, and_op):
        """Sets the and_op of this InvestigationFilter.


        :param and_op: The and_op of this InvestigationFilter.  # noqa: E501
        :type: bool
        """

        self._and_op = and_op

    @property
    def category(self):
        """Gets the category of this InvestigationFilter.  # noqa: E501


        :return: The category of this InvestigationFilter.  # noqa: E501
        :rtype: list[str]
        """
        return self._category

    @category.setter
    def category(self, category):
        """Sets the category of this InvestigationFilter.


        :param category: The category of this InvestigationFilter.  # noqa: E501
        :type: list[str]
        """

        self._category = category

    @property
    def from_close_date(self):
        """Gets the from_close_date of this InvestigationFilter.  # noqa: E501


        :return: The from_close_date of this InvestigationFilter.  # noqa: E501
        :rtype: datetime
        """
        return self._from_close_date

    @from_close_date.setter
    def from_close_date(self, from_close_date):
        """Sets the from_close_date of this InvestigationFilter.


        :param from_close_date: The from_close_date of this InvestigationFilter.  # noqa: E501
        :type: datetime
        """

        self._from_close_date = from_close_date

    @property
    def from_date(self):
        """Gets the from_date of this InvestigationFilter.  # noqa: E501


        :return: The from_date of this InvestigationFilter.  # noqa: E501
        :rtype: datetime
        """
        return self._from_date

    @from_date.setter
    def from_date(self, from_date):
        """Sets the from_date of this InvestigationFilter.


        :param from_date: The from_date of this InvestigationFilter.  # noqa: E501
        :type: datetime
        """

        self._from_date = from_date

    @property
    def from_date_license(self):
        """Gets the from_date_license of this InvestigationFilter.  # noqa: E501


        :return: The from_date_license of this InvestigationFilter.  # noqa: E501
        :rtype: datetime
        """
        return self._from_date_license

    @from_date_license.setter
    def from_date_license(self, from_date_license):
        """Sets the from_date_license of this InvestigationFilter.


        :param from_date_license: The from_date_license of this InvestigationFilter.  # noqa: E501
        :type: datetime
        """

        self._from_date_license = from_date_license

    @property
    def id(self):
        """Gets the id of this InvestigationFilter.  # noqa: E501


        :return: The id of this InvestigationFilter.  # noqa: E501
        :rtype: list[str]
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this InvestigationFilter.


        :param id: The id of this InvestigationFilter.  # noqa: E501
        :type: list[str]
        """

        self._id = id

    @property
    def ids_only(self):
        """Gets the ids_only of this InvestigationFilter.  # noqa: E501


        :return: The ids_only of this InvestigationFilter.  # noqa: E501
        :rtype: bool
        """
        return self._ids_only

    @ids_only.setter
    def ids_only(self, ids_only):
        """Sets the ids_only of this InvestigationFilter.


        :param ids_only: The ids_only of this InvestigationFilter.  # noqa: E501
        :type: bool
        """

        self._ids_only = ids_only

    @property
    def include_child_inv(self):
        """Gets the include_child_inv of this InvestigationFilter.  # noqa: E501


        :return: The include_child_inv of this InvestigationFilter.  # noqa: E501
        :rtype: bool
        """
        return self._include_child_inv

    @include_child_inv.setter
    def include_child_inv(self, include_child_inv):
        """Sets the include_child_inv of this InvestigationFilter.


        :param include_child_inv: The include_child_inv of this InvestigationFilter.  # noqa: E501
        :type: bool
        """

        self._include_child_inv = include_child_inv

    @property
    def name(self):
        """Gets the name of this InvestigationFilter.  # noqa: E501


        :return: The name of this InvestigationFilter.  # noqa: E501
        :rtype: list[str]
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this InvestigationFilter.


        :param name: The name of this InvestigationFilter.  # noqa: E501
        :type: list[str]
        """

        self._name = name

    @property
    def not_category(self):
        """Gets the not_category of this InvestigationFilter.  # noqa: E501


        :return: The not_category of this InvestigationFilter.  # noqa: E501
        :rtype: list[str]
        """
        return self._not_category

    @not_category.setter
    def not_category(self, not_category):
        """Sets the not_category of this InvestigationFilter.


        :param not_category: The not_category of this InvestigationFilter.  # noqa: E501
        :type: list[str]
        """

        self._not_category = not_category

    @property
    def not_i_ds(self):
        """Gets the not_i_ds of this InvestigationFilter.  # noqa: E501


        :return: The not_i_ds of this InvestigationFilter.  # noqa: E501
        :rtype: list[str]
        """
        return self._not_i_ds

    @not_i_ds.setter
    def not_i_ds(self, not_i_ds):
        """Sets the not_i_ds of this InvestigationFilter.


        :param not_i_ds: The not_i_ds of this InvestigationFilter.  # noqa: E501
        :type: list[str]
        """

        self._not_i_ds = not_i_ds

    @property
    def page(self):
        """Gets the page of this InvestigationFilter.  # noqa: E501

        0-based page  # noqa: E501

        :return: The page of this InvestigationFilter.  # noqa: E501
        :rtype: int
        """
        return self._page

    @page.setter
    def page(self, page):
        """Sets the page of this InvestigationFilter.

        0-based page  # noqa: E501

        :param page: The page of this InvestigationFilter.  # noqa: E501
        :type: int
        """

        self._page = page

    @property
    def period(self):
        """Gets the period of this InvestigationFilter.  # noqa: E501


        :return: The period of this InvestigationFilter.  # noqa: E501
        :rtype: Period
        """
        return self._period

    @period.setter
    def period(self, period):
        """Sets the period of this InvestigationFilter.


        :param period: The period of this InvestigationFilter.  # noqa: E501
        :type: Period
        """

        self._period = period

    @property
    def reason(self):
        """Gets the reason of this InvestigationFilter.  # noqa: E501


        :return: The reason of this InvestigationFilter.  # noqa: E501
        :rtype: list[str]
        """
        return self._reason

    @reason.setter
    def reason(self, reason):
        """Sets the reason of this InvestigationFilter.


        :param reason: The reason of this InvestigationFilter.  # noqa: E501
        :type: list[str]
        """

        self._reason = reason

    @property
    def search_after(self):
        """Gets the search_after of this InvestigationFilter.  # noqa: E501

        Efficient next page, pass max sort value from previous page  # noqa: E501

        :return: The search_after of this InvestigationFilter.  # noqa: E501
        :rtype: list[str]
        """
        return self._search_after

    @search_after.setter
    def search_after(self, search_after):
        """Sets the search_after of this InvestigationFilter.

        Efficient next page, pass max sort value from previous page  # noqa: E501

        :param search_after: The search_after of this InvestigationFilter.  # noqa: E501
        :type: list[str]
        """

        self._search_after = search_after

    @property
    def search_before(self):
        """Gets the search_before of this InvestigationFilter.  # noqa: E501

        Efficient prev page, pass min sort value from next page  # noqa: E501

        :return: The search_before of this InvestigationFilter.  # noqa: E501
        :rtype: list[str]
        """
        return self._search_before

    @search_before.setter
    def search_before(self, search_before):
        """Sets the search_before of this InvestigationFilter.

        Efficient prev page, pass min sort value from next page  # noqa: E501

        :param search_before: The search_before of this InvestigationFilter.  # noqa: E501
        :type: list[str]
        """

        self._search_before = search_before

    @property
    def size(self):
        """Gets the size of this InvestigationFilter.  # noqa: E501

        Size is limited to 1000, if not passed it defaults to 0, and no results will return  # noqa: E501

        :return: The size of this InvestigationFilter.  # noqa: E501
        :rtype: int
        """
        return self._size

    @size.setter
    def size(self, size):
        """Sets the size of this InvestigationFilter.

        Size is limited to 1000, if not passed it defaults to 0, and no results will return  # noqa: E501

        :param size: The size of this InvestigationFilter.  # noqa: E501
        :type: int
        """

        self._size = size

    @property
    def sort(self):
        """Gets the sort of this InvestigationFilter.  # noqa: E501

        The sort order  # noqa: E501

        :return: The sort of this InvestigationFilter.  # noqa: E501
        :rtype: list[Order]
        """
        return self._sort

    @sort.setter
    def sort(self, sort):
        """Sets the sort of this InvestigationFilter.

        The sort order  # noqa: E501

        :param sort: The sort of this InvestigationFilter.  # noqa: E501
        :type: list[Order]
        """

        self._sort = sort

    @property
    def status(self):
        """Gets the status of this InvestigationFilter.  # noqa: E501


        :return: The status of this InvestigationFilter.  # noqa: E501
        :rtype: list[InvestigationStatus]
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this InvestigationFilter.


        :param status: The status of this InvestigationFilter.  # noqa: E501
        :type: list[InvestigationStatus]
        """

        self._status = status

    @property
    def time_frame(self):
        """Gets the time_frame of this InvestigationFilter.  # noqa: E501


        :return: The time_frame of this InvestigationFilter.  # noqa: E501
        :rtype: Duration
        """
        return self._time_frame

    @time_frame.setter
    def time_frame(self, time_frame):
        """Sets the time_frame of this InvestigationFilter.


        :param time_frame: The time_frame of this InvestigationFilter.  # noqa: E501
        :type: Duration
        """

        self._time_frame = time_frame

    @property
    def to_close_date(self):
        """Gets the to_close_date of this InvestigationFilter.  # noqa: E501


        :return: The to_close_date of this InvestigationFilter.  # noqa: E501
        :rtype: datetime
        """
        return self._to_close_date

    @to_close_date.setter
    def to_close_date(self, to_close_date):
        """Sets the to_close_date of this InvestigationFilter.


        :param to_close_date: The to_close_date of this InvestigationFilter.  # noqa: E501
        :type: datetime
        """

        self._to_close_date = to_close_date

    @property
    def to_date(self):
        """Gets the to_date of this InvestigationFilter.  # noqa: E501


        :return: The to_date of this InvestigationFilter.  # noqa: E501
        :rtype: datetime
        """
        return self._to_date

    @to_date.setter
    def to_date(self, to_date):
        """Sets the to_date of this InvestigationFilter.


        :param to_date: The to_date of this InvestigationFilter.  # noqa: E501
        :type: datetime
        """

        self._to_date = to_date

    @property
    def type(self):
        """Gets the type of this InvestigationFilter.  # noqa: E501


        :return: The type of this InvestigationFilter.  # noqa: E501
        :rtype: list[InvestigationType]
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this InvestigationFilter.


        :param type: The type of this InvestigationFilter.  # noqa: E501
        :type: list[InvestigationType]
        """

        self._type = type

    @property
    def user(self):
        """Gets the user of this InvestigationFilter.  # noqa: E501


        :return: The user of this InvestigationFilter.  # noqa: E501
        :rtype: list[str]
        """
        return self._user

    @user.setter
    def user(self, user):
        """Sets the user of this InvestigationFilter.


        :param user: The user of this InvestigationFilter.  # noqa: E501
        :type: list[str]
        """

        self._user = user

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InvestigationFilter, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InvestigationFilter):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from __future__ import print_function
import demisto_client.demisto_api
from demisto_client.demisto_api.rest import ApiException
from pprint import pprint

api_key = 'YOUR API KEY'
base_url = 'YOUR DEMISTO URL'

# create an instance of the API class
api_instance = demisto_client.configure(base_url=base_url, api_key=api_key, debug=False)
update_data_batch = demisto_client.demisto_api.UpdateDataBatch()

update_data_batch.ids = ['1001', '1002', '1003']
update_data_batch.close_notes = 'Incident is a duplicate to incident 1000'
update_data_batch.close_reason = 'Closed as duplicate'

try:
    # Batch close incidents
    api_response = api_instance.close_incidents_batch(update_data_batch=update_data_batch)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling DefaultApi->close_incidents_batch: %s\n" % e)



# coding: utf-8

"""
    Demisto API

    This is the public REST API to integrate with the demisto server. HTTP request can be sent using any HTTP-client.  For an example dedicated client take a look at: https://github.com/demisto/demisto-py.  Requests must include API-key that can be generated in the Demisto web client under 'Settings' -> 'Integrations' -> 'API keys'   Optimistic Locking and Versioning\\:  When using Demisto REST API, you will need to make sure to work on the latest version of the item (incident, entry, etc.), otherwise, you will get a DB version error (which not allow you to override a newer item). In addition, you can pass 'version\\: -1' to force data override (make sure that other users data might be lost).  Assume that Alice and Bob both read the same data from Demisto server, then they both changed the data, and then both tried to write the new versions back to the server. Whose changes should be saved? Alice’s? Bob’s? To solve this, each data item in Demisto has a numeric incremental version. If Alice saved an item with version 4 and Bob trying to save the same item with version 3, Demisto will rollback Bob request and returns a DB version conflict error. Bob will need to get the latest item and work on it so Alice work will not get lost.  Example request using 'curl'\\:  ``` curl 'https://hostname:443/incidents/search' -H 'content-type: application/json' -H 'accept: application/json' -H 'Authorization: <API Key goes here>' --data-binary '{\"filter\":{\"query\":\"-status:closed -category:job\",\"period\":{\"by\":\"day\",\"fromValue\":7}}}' --compressed ```  # noqa: E501

    OpenAPI spec version: 2.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from demisto_client.demisto_api.models.advance_arg import AdvanceArg  # noqa: F401,E501
from demisto_client.demisto_api.models.notify_timings import NotifyTimings  # noqa: F401,E501


class NotifiableItem(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'bcc': 'AdvanceArg',
        'body': 'AdvanceArg',
        'cc': 'AdvanceArg',
        'default_option': 'str',
        'format': 'str',
        'methods': 'list[str]',
        'reply_options': 'list[str]',
        'subject': 'AdvanceArg',
        'timings': 'NotifyTimings',
        'to': 'AdvanceArg'
    }

    attribute_map = {
        'bcc': 'bcc',
        'body': 'body',
        'cc': 'cc',
        'default_option': 'defaultOption',
        'format': 'format',
        'methods': 'methods',
        'reply_options': 'replyOptions',
        'subject': 'subject',
        'timings': 'timings',
        'to': 'to'
    }

    def __init__(self, bcc=None, body=None, cc=None, default_option=None, format=None, methods=None, reply_options=None, subject=None, timings=None, to=None):  # noqa: E501
        """NotifiableItem - a model defined in Swagger"""  # noqa: E501

        self._bcc = None
        self._body = None
        self._cc = None
        self._default_option = None
        self._format = None
        self._methods = None
        self._reply_options = None
        self._subject = None
        self._timings = None
        self._to = None
        self.discriminator = None

        if bcc is not None:
            self.bcc = bcc
        if body is not None:
            self.body = body
        if cc is not None:
            self.cc = cc
        if default_option is not None:
            self.default_option = default_option
        if format is not None:
            self.format = format
        if methods is not None:
            self.methods = methods
        if reply_options is not None:
            self.reply_options = reply_options
        if subject is not None:
            self.subject = subject
        if timings is not None:
            self.timings = timings
        if to is not None:
            self.to = to

    @property
    def bcc(self):
        """Gets the bcc of this NotifiableItem.  # noqa: E501


        :return: The bcc of this NotifiableItem.  # noqa: E501
        :rtype: AdvanceArg
        """
        return self._bcc

    @bcc.setter
    def bcc(self, bcc):
        """Sets the bcc of this NotifiableItem.


        :param bcc: The bcc of this NotifiableItem.  # noqa: E501
        :type: AdvanceArg
        """

        self._bcc = bcc

    @property
    def body(self):
        """Gets the body of this NotifiableItem.  # noqa: E501


        :return: The body of this NotifiableItem.  # noqa: E501
        :rtype: AdvanceArg
        """
        return self._body

    @body.setter
    def body(self, body):
        """Sets the body of this NotifiableItem.


        :param body: The body of this NotifiableItem.  # noqa: E501
        :type: AdvanceArg
        """

        self._body = body

    @property
    def cc(self):
        """Gets the cc of this NotifiableItem.  # noqa: E501


        :return: The cc of this NotifiableItem.  # noqa: E501
        :rtype: AdvanceArg
        """
        return self._cc

    @cc.setter
    def cc(self, cc):
        """Sets the cc of this NotifiableItem.


        :param cc: The cc of this NotifiableItem.  # noqa: E501
        :type: AdvanceArg
        """

        self._cc = cc

    @property
    def default_option(self):
        """Gets the default_option of this NotifiableItem.  # noqa: E501


        :return: The default_option of this NotifiableItem.  # noqa: E501
        :rtype: str
        """
        return self._default_option

    @default_option.setter
    def default_option(self, default_option):
        """Sets the default_option of this NotifiableItem.


        :param default_option: The default_option of this NotifiableItem.  # noqa: E501
        :type: str
        """

        self._default_option = default_option

    @property
    def format(self):
        """Gets the format of this NotifiableItem.  # noqa: E501


        :return: The format of this NotifiableItem.  # noqa: E501
        :rtype: str
        """
        return self._format

    @format.setter
    def format(self, format):
        """Sets the format of this NotifiableItem.


        :param format: The format of this NotifiableItem.  # noqa: E501
        :type: str
        """

        self._format = format

    @property
    def methods(self):
        """Gets the methods of this NotifiableItem.  # noqa: E501


        :return: The methods of this NotifiableItem.  # noqa: E501
        :rtype: list[str]
        """
        return self._methods

    @methods.setter
    def methods(self, methods):
        """Sets the methods of this NotifiableItem.


        :param methods: The methods of this NotifiableItem.  # noqa: E501
        :type: list[str]
        """

        self._methods = methods

    @property
    def reply_options(self):
        """Gets the reply_options of this NotifiableItem.  # noqa: E501


        :return: The reply_options of this NotifiableItem.  # noqa: E501
        :rtype: list[str]
        """
        return self._reply_options

    @reply_options.setter
    def reply_options(self, reply_options):
        """Sets the reply_options of this NotifiableItem.


        :param reply_options: The reply_options of this NotifiableItem.  # noqa: E501
        :type: list[str]
        """

        self._reply_options = reply_options

    @property
    def subject(self):
        """Gets the subject of this NotifiableItem.  # noqa: E501


        :return: The subject of this NotifiableItem.  # noqa: E501
        :rtype: AdvanceArg
        """
        return self._subject

    @subject.setter
    def subject(self, subject):
        """Sets the subject of this NotifiableItem.


        :param subject: The subject of this NotifiableItem.  # noqa: E501
        :type: AdvanceArg
        """

        self._subject = subject

    @property
    def timings(self):
        """Gets the timings of this NotifiableItem.  # noqa: E501


        :return: The timings of this NotifiableItem.  # noqa: E501
        :rtype: NotifyTimings
        """
        return self._timings

    @timings.setter
    def timings(self, timings):
        """Sets the timings of this NotifiableItem.


        :param timings: The timings of this NotifiableItem.  # noqa: E501
        :type: NotifyTimings
        """

        self._timings = timings

    @property
    def to(self):
        """Gets the to of this NotifiableItem.  # noqa: E501


        :return: The to of this NotifiableItem.  # noqa: E501
        :rtype: AdvanceArg
        """
        return self._to

    @to.setter
    def to(self, to):
        """Sets the to of this NotifiableItem.


        :param to: The to of this NotifiableItem.  # noqa: E501
        :type: AdvanceArg
        """

        self._to = to

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(NotifiableItem, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, NotifiableItem):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Demisto API

    This is the public REST API to integrate with the demisto server. HTTP request can be sent using any HTTP-client.  For an example dedicated client take a look at: https://github.com/demisto/demisto-py.  Requests must include API-key that can be generated in the Demisto web client under 'Settings' -> 'Integrations' -> 'API keys'   Optimistic Locking and Versioning\\:  When using Demisto REST API, you will need to make sure to work on the latest version of the item (incident, entry, etc.), otherwise, you will get a DB version error (which not allow you to override a newer item). In addition, you can pass 'version\\: -1' to force data override (make sure that other users data might be lost).  Assume that Alice and Bob both read the same data from Demisto server, then they both changed the data, and then both tried to write the new versions back to the server. Whose changes should be saved? Alice’s? Bob’s? To solve this, each data item in Demisto has a numeric incremental version. If Alice saved an item with version 4 and Bob trying to save the same item with version 3, Demisto will rollback Bob request and returns a DB version conflict error. Bob will need to get the latest item and work on it so Alice work will not get lost.  Example request using 'curl'\\:  ``` curl 'https://hostname:443/incidents/search' -H 'content-type: application/json' -H 'accept: application/json' -H 'Authorization: <API Key goes here>' --data-binary '{\"filter\":{\"query\":\"-status:closed -category:job\",\"period\":{\"by\":\"day\",\"fromValue\":7}}}' --compressed ```  # noqa: E501

    OpenAPI spec version: 2.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from demisto_client.demisto_api.models.advance_arg import AdvanceArg  # noqa: F401,E501
from demisto_client.demisto_api.models.data_collection_form import DataCollectionForm  # noqa: F401,E501
from demisto_client.demisto_api.models.evidence_data import EvidenceData  # noqa: F401,E501
from demisto_client.demisto_api.models.field_mapping import FieldMapping  # noqa: F401,E501
from demisto_client.demisto_api.models.form_display import FormDisplay  # noqa: F401,E501
from demisto_client.demisto_api.models.notifiable_item import NotifiableItem  # noqa: F401,E501
from demisto_client.demisto_api.models.quiet_mode import QuietMode  # noqa: F401,E501
from demisto_client.demisto_api.models.reputation_calc_alg import ReputationCalcAlg  # noqa: F401,E501
from demisto_client.demisto_api.models.sla import SLA  # noqa: F401,E501
from demisto_client.demisto_api.models.task import Task  # noqa: F401,E501
from demisto_client.demisto_api.models.task_condition import TaskCondition  # noqa: F401,E501
from demisto_client.demisto_api.models.task_loop import TaskLoop  # noqa: F401,E501
from demisto_client.demisto_api.models.task_type import TaskType  # noqa: F401,E501
from demisto_client.demisto_api.models.task_view import TaskView  # noqa: F401,E501
from demisto_client.demisto_api.models.timer_trigger import TimerTrigger  # noqa: F401,E501


class PlaybookTask(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'conditions': 'list[TaskCondition]',
        'continue_on_error': 'bool',
        'default_assignee': 'str',
        'default_assignee_complex': 'AdvanceArg',
        'default_reminder': 'int',
        'evidence_data': 'EvidenceData',
        'field_mapping': 'list[FieldMapping]',
        'form': 'DataCollectionForm',
        'form_display': 'FormDisplay',
        'id': 'str',
        'ignore_worker': 'bool',
        'loop': 'TaskLoop',
        'message': 'NotifiableItem',
        'next_tasks': 'dict(str, list[str])',
        'note': 'bool',
        'quiet_mode': 'QuietMode',
        'reputation_calc': 'ReputationCalcAlg',
        'restricted_completion': 'bool',
        'script_arguments': 'dict(str, AdvanceArg)',
        'separate_context': 'bool',
        'skip_unavailable': 'bool',
        'sla': 'SLA',
        'sla_reminder': 'SLA',
        'task': 'Task',
        'task_id': 'str',
        'timer_triggers': 'list[TimerTrigger]',
        'type': 'TaskType',
        'view': 'TaskView'
    }

    attribute_map = {
        'conditions': 'conditions',
        'continue_on_error': 'continueOnError',
        'default_assignee': 'defaultAssignee',
        'default_assignee_complex': 'defaultAssigneeComplex',
        'default_reminder': 'defaultReminder',
        'evidence_data': 'evidenceData',
        'field_mapping': 'fieldMapping',
        'form': 'form',
        'form_display': 'formDisplay',
        'id': 'id',
        'ignore_worker': 'ignoreWorker',
        'loop': 'loop',
        'message': 'message',
        'next_tasks': 'nextTasks',
        'note': 'note',
        'quiet_mode': 'quietMode',
        'reputation_calc': 'reputationCalc',
        'restricted_completion': 'restrictedCompletion',
        'script_arguments': 'scriptArguments',
        'separate_context': 'separateContext',
        'skip_unavailable': 'skipUnavailable',
        'sla': 'sla',
        'sla_reminder': 'slaReminder',
        'task': 'task',
        'task_id': 'taskId',
        'timer_triggers': 'timerTriggers',
        'type': 'type',
        'view': 'view'
    }

    def __init__(self, conditions=None, continue_on_error=None, default_assignee=None, default_assignee_complex=None, default_reminder=None, evidence_data=None, field_mapping=None, form=None, form_display=None, id=None, ignore_worker=None, loop=None, message=None, next_tasks=None, note=None, quiet_mode=None, reputation_calc=None, restricted_completion=None, script_arguments=None, separate_context=None, skip_unavailable=None, sla=None, sla_reminder=None, task=None, task_id=None, timer_triggers=None, type=None, view=None):  # noqa: E501
        """PlaybookTask - a model defined in Swagger"""  # noqa: E501

        self._conditions = None
        self._continue_on_error = None
        self._default_assignee = None
        self._default_assignee_complex = None
        self._default_reminder = None
        self._evidence_data = None
        self._field_mapping = None
        self._form = None
        self._form_display = None
        self._id = None
        self._ignore_worker = None
        self._loop = None
        self._message = None
        self._next_tasks = None
        self._note = None
        self._quiet_mode = None
        self._reputation_calc = None
        self._restricted_completion = None
        self._script_arguments = None
        self._separate_context = None
        self._skip_unavailable = None
        self._sla = None
        self._sla_reminder = None
        self._task = None
        self._task_id = None
        self._timer_triggers = None
        self._type = None
        self._view = None
        self.discriminator = None

        if conditions is not None:
            self.conditions = conditions
        if continue_on_error is not None:
            self.continue_on_error = continue_on_error
        if default_assignee is not None:
            self.default_assignee = default_assignee
        if default_assignee_complex is not None:
            self.default_assignee_complex = default_assignee_complex
        if default_reminder is not None:
            self.default_reminder = default_reminder
        if evidence_data is not None:
            self.evidence_data = evidence_data
        if field_mapping is not None:
            self.field_mapping = field_mapping
        if form is not None:
            self.form = form
        if form_display is not None:
            self.form_display = form_display
        if id is not None:
            self.id = id
        if ignore_worker is not None:
            self.ignore_worker = ignore_worker
        if loop is not None:
            self.loop = loop
        if message is not None:
            self.message = message
        if next_tasks is not None:
            self.next_tasks = next_tasks
        if note is not None:
            self.note = note
        if quiet_mode is not None:
            self.quiet_mode = quiet_mode
        if reputation_calc is not None:
            self.reputation_calc = reputation_calc
        if restricted_completion is not None:
            self.restricted_completion = restricted_completion
        if script_arguments is not None:
            self.script_arguments = script_arguments
        if separate_context is not None:
            self.separate_context = separate_context
        if skip_unavailable is not None:
            self.skip_unavailable = skip_unavailable
        if sla is not None:
            self.sla = sla
        if sla_reminder is not None:
            self.sla_reminder = sla_reminder
        if task is not None:
            self.task = task
        if task_id is not None:
            self.task_id = task_id
        if timer_triggers is not None:
            self.timer_triggers = timer_triggers
        if type is not None:
            self.type = type
        if view is not None:
            self.view = view

    @property
    def conditions(self):
        """Gets the conditions of this PlaybookTask.  # noqa: E501

        Conditions - optional list of conditions to run when task is conditional. we check conditions by their order (e.i. - considering the first one that satisfied)  # noqa: E501

        :return: The conditions of this PlaybookTask.  # noqa: E501
        :rtype: list[TaskCondition]
        """
        return self._conditions

    @conditions.setter
    def conditions(self, conditions):
        """Sets the conditions of this PlaybookTask.

        Conditions - optional list of conditions to run when task is conditional. we check conditions by their order (e.i. - considering the first one that satisfied)  # noqa: E501

        :param conditions: The conditions of this PlaybookTask.  # noqa: E501
        :type: list[TaskCondition]
        """

        self._conditions = conditions

    @property
    def continue_on_error(self):
        """Gets the continue_on_error of this PlaybookTask.  # noqa: E501


        :return: The continue_on_error of this PlaybookTask.  # noqa: E501
        :rtype: bool
        """
        return self._continue_on_error

    @continue_on_error.setter
    def continue_on_error(self, continue_on_error):
        """Sets the continue_on_error of this PlaybookTask.


        :param continue_on_error: The continue_on_error of this PlaybookTask.  # noqa: E501
        :type: bool
        """

        self._continue_on_error = continue_on_error

    @property
    def default_assignee(self):
        """Gets the default_assignee of this PlaybookTask.  # noqa: E501


        :return: The default_assignee of this PlaybookTask.  # noqa: E501
        :rtype: str
        """
        return self._default_assignee

    @default_assignee.setter
    def default_assignee(self, default_assignee):
        """Sets the default_assignee of this PlaybookTask.


        :param default_assignee: The default_assignee of this PlaybookTask.  # noqa: E501
        :type: str
        """

        self._default_assignee = default_assignee

    @property
    def default_assignee_complex(self):
        """Gets the default_assignee_complex of this PlaybookTask.  # noqa: E501


        :return: The default_assignee_complex of this PlaybookTask.  # noqa: E501
        :rtype: AdvanceArg
        """
        return self._default_assignee_complex

    @default_assignee_complex.setter
    def default_assignee_complex(self, default_assignee_complex):
        """Sets the default_assignee_complex of this PlaybookTask.


        :param default_assignee_complex: The default_assignee_complex of this PlaybookTask.  # noqa: E501
        :type: AdvanceArg
        """

        self._default_assignee_complex = default_assignee_complex

    @property
    def default_reminder(self):
        """Gets the default_reminder of this PlaybookTask.  # noqa: E501


        :return: The default_reminder of this PlaybookTask.  # noqa: E501
        :rtype: int
        """
        return self._default_reminder

    @default_reminder.setter
    def default_reminder(self, default_reminder):
        """Sets the default_reminder of this PlaybookTask.


        :param default_reminder: The default_reminder of this PlaybookTask.  # noqa: E501
        :type: int
        """

        self._default_reminder = default_reminder

    @property
    def evidence_data(self):
        """Gets the evidence_data of this PlaybookTask.  # noqa: E501


        :return: The evidence_data of this PlaybookTask.  # noqa: E501
        :rtype: EvidenceData
        """
        return self._evidence_data

    @evidence_data.setter
    def evidence_data(self, evidence_data):
        """Sets the evidence_data of this PlaybookTask.


        :param evidence_data: The evidence_data of this PlaybookTask.  # noqa: E501
        :type: EvidenceData
        """

        self._evidence_data = evidence_data

    @property
    def field_mapping(self):
        """Gets the field_mapping of this PlaybookTask.  # noqa: E501


        :return: The field_mapping of this PlaybookTask.  # noqa: E501
        :rtype: list[FieldMapping]
        """
        return self._field_mapping

    @field_mapping.setter
    def field_mapping(self, field_mapping):
        """Sets the field_mapping of this PlaybookTask.


        :param field_mapping: The field_mapping of this PlaybookTask.  # noqa: E501
        :type: list[FieldMapping]
        """

        self._field_mapping = field_mapping

    @property
    def form(self):
        """Gets the form of this PlaybookTask.  # noqa: E501


        :return: The form of this PlaybookTask.  # noqa: E501
        :rtype: DataCollectionForm
        """
        return self._form

    @form.setter
    def form(self, form):
        """Sets the form of this PlaybookTask.


        :param form: The form of this PlaybookTask.  # noqa: E501
        :type: DataCollectionForm
        """

        self._form = form

    @property
    def form_display(self):
        """Gets the form_display of this PlaybookTask.  # noqa: E501


        :return: The form_display of this PlaybookTask.  # noqa: E501
        :rtype: FormDisplay
        """
        return self._form_display

    @form_display.setter
    def form_display(self, form_display):
        """Sets the form_display of this PlaybookTask.


        :param form_display: The form_display of this PlaybookTask.  # noqa: E501
        :type: FormDisplay
        """

        self._form_display = form_display

    @property
    def id(self):
        """Gets the id of this PlaybookTask.  # noqa: E501


        :return: The id of this PlaybookTask.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this PlaybookTask.


        :param id: The id of this PlaybookTask.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def ignore_worker(self):
        """Gets the ignore_worker of this PlaybookTask.  # noqa: E501

        Do not run this task in a worker  # noqa: E501

        :return: The ignore_worker of this PlaybookTask.  # noqa: E501
        :rtype: bool
        """
        return self._ignore_worker

    @ignore_worker.setter
    def ignore_worker(self, ignore_worker):
        """Sets the ignore_worker of this PlaybookTask.

        Do not run this task in a worker  # noqa: E501

        :param ignore_worker: The ignore_worker of this PlaybookTask.  # noqa: E501
        :type: bool
        """

        self._ignore_worker = ignore_worker

    @property
    def loop(self):
        """Gets the loop of this PlaybookTask.  # noqa: E501


        :return: The loop of this PlaybookTask.  # noqa: E501
        :rtype: TaskLoop
        """
        return self._loop

    @loop.setter
    def loop(self, loop):
        """Sets the loop of this PlaybookTask.


        :param loop: The loop of this PlaybookTask.  # noqa: E501
        :type: TaskLoop
        """

        self._loop = loop

    @property
    def message(self):
        """Gets the message of this PlaybookTask.  # noqa: E501


        :return: The message of this PlaybookTask.  # noqa: E501
        :rtype: NotifiableItem
        """
        return self._message

    @message.setter
    def message(self, message):
        """Sets the message of this PlaybookTask.


        :param message: The message of this PlaybookTask.  # noqa: E501
        :type: NotifiableItem
        """

        self._message = message

    @property
    def next_tasks(self):
        """Gets the next_tasks of this PlaybookTask.  # noqa: E501


        :return: The next_tasks of this PlaybookTask.  # noqa: E501
        :rtype: dict(str, list[str])
        """
        return self._next_tasks

    @next_tasks.setter
    def next_tasks(self, next_tasks):
        """Sets the next_tasks of this PlaybookTask.


        :param next_tasks: The next_tasks of this PlaybookTask.  # noqa: E501
        :type: dict(str, list[str])
        """

        self._next_tasks = next_tasks

    @property
    def note(self):
        """Gets the note of this PlaybookTask.  # noqa: E501


        :return: The note of this PlaybookTask.  # noqa: E501
        :rtype: bool
        """
        return self._note

    @note.setter
    def note(self, note):
        """Sets the note of this PlaybookTask.


        :param note: The note of this PlaybookTask.  # noqa: E501
        :type: bool
        """

        self._note = note

    @property
    def quiet_mode(self):
        """Gets the quiet_mode of this PlaybookTask.  # noqa: E501


        :return: The quiet_mode of this PlaybookTask.  # noqa: E501
        :rtype: QuietMode
        """
        return self._quiet_mode

    @quiet_mode.setter
    def quiet_mode(self, quiet_mode):
        """Sets the quiet_mode of this PlaybookTask.


        :param quiet_mode: The quiet_mode of this PlaybookTask.  # noqa: E501
        :type: QuietMode
        """

        self._quiet_mode = quiet_mode

    @property
    def reputation_calc(self):
        """Gets the reputation_calc of this PlaybookTask.  # noqa: E501


        :return: The reputation_calc of this PlaybookTask.  # noqa: E501
        :rtype: ReputationCalcAlg
        """
        return self._reputation_calc

    @reputation_calc.setter
    def reputation_calc(self, reputation_calc):
        """Sets the reputation_calc of this PlaybookTask.


        :param reputation_calc: The reputation_calc of this PlaybookTask.  # noqa: E501
        :type: ReputationCalcAlg
        """

        self._reputation_calc = reputation_calc

    @property
    def restricted_completion(self):
        """Gets the restricted_completion of this PlaybookTask.  # noqa: E501


        :return: The restricted_completion of this PlaybookTask.  # noqa: E501
        :rtype: bool
        """
        return self._restricted_completion

    @restricted_completion.setter
    def restricted_completion(self, restricted_completion):
        """Sets the restricted_completion of this PlaybookTask.


        :param restricted_completion: The restricted_completion of this PlaybookTask.  # noqa: E501
        :type: bool
        """

        self._restricted_completion = restricted_completion

    @property
    def script_arguments(self):
        """Gets the script_arguments of this PlaybookTask.  # noqa: E501


        :return: The script_arguments of this PlaybookTask.  # noqa: E501
        :rtype: dict(str, AdvanceArg)
        """
        return self._script_arguments

    @script_arguments.setter
    def script_arguments(self, script_arguments):
        """Sets the script_arguments of this PlaybookTask.


        :param script_arguments: The script_arguments of this PlaybookTask.  # noqa: E501
        :type: dict(str, AdvanceArg)
        """

        self._script_arguments = script_arguments

    @property
    def separate_context(self):
        """Gets the separate_context of this PlaybookTask.  # noqa: E501


        :return: The separate_context of this PlaybookTask.  # noqa: E501
        :rtype: bool
        """
        return self._separate_context

    @separate_context.setter
    def separate_context(self, separate_context):
        """Sets the separate_context of this PlaybookTask.


        :param separate_context: The separate_context of this PlaybookTask.  # noqa: E501
        :type: bool
        """

        self._separate_context = separate_context

    @property
    def skip_unavailable(self):
        """Gets the skip_unavailable of this PlaybookTask.  # noqa: E501

        SkipUnavailable if true then will check if automation exists, integration of that command is installed and active or sub playbook exists in Demisto  # noqa: E501

        :return: The skip_unavailable of this PlaybookTask.  # noqa: E501
        :rtype: bool
        """
        return self._skip_unavailable

    @skip_unavailable.setter
    def skip_unavailable(self, skip_unavailable):
        """Sets the skip_unavailable of this PlaybookTask.

        SkipUnavailable if true then will check if automation exists, integration of that command is installed and active or sub playbook exists in Demisto  # noqa: E501

        :param skip_unavailable: The skip_unavailable of this PlaybookTask.  # noqa: E501
        :type: bool
        """

        self._skip_unavailable = skip_unavailable

    @property
    def sla(self):
        """Gets the sla of this PlaybookTask.  # noqa: E501


        :return: The sla of this PlaybookTask.  # noqa: E501
        :rtype: SLA
        """
        return self._sla

    @sla.setter
    def sla(self, sla):
        """Sets the sla of this PlaybookTask.


        :param sla: The sla of this PlaybookTask.  # noqa: E501
        :type: SLA
        """

        self._sla = sla

    @property
    def sla_reminder(self):
        """Gets the sla_reminder of this PlaybookTask.  # noqa: E501


        :return: The sla_reminder of this PlaybookTask.  # noqa: E501
        :rtype: SLA
        """
        return self._sla_reminder

    @sla_reminder.setter
    def sla_reminder(self, sla_reminder):
        """Sets the sla_reminder of this PlaybookTask.


        :param sla_reminder: The sla_reminder of this PlaybookTask.  # noqa: E501
        :type: SLA
        """

        self._sla_reminder = sla_reminder

    @property
    def task(self):
        """Gets the task of this PlaybookTask.  # noqa: E501


        :return: The task of this PlaybookTask.  # noqa: E501
        :rtype: Task
        """
        return self._task

    @task.setter
    def task(self, task):
        """Sets the task of this PlaybookTask.


        :param task: The task of this PlaybookTask.  # noqa: E501
        :type: Task
        """

        self._task = task

    @property
    def task_id(self):
        """Gets the task_id of this PlaybookTask.  # noqa: E501


        :return: The task_id of this PlaybookTask.  # noqa: E501
        :rtype: str
        """
        return self._task_id

    @task_id.setter
    def task_id(self, task_id):
        """Sets the task_id of this PlaybookTask.


        :param task_id: The task_id of this PlaybookTask.  # noqa: E501
        :type: str
        """

        self._task_id = task_id

    @property
    def timer_triggers(self):
        """Gets the timer_triggers of this PlaybookTask.  # noqa: E501

        SLA fields  # noqa: E501

        :return: The timer_triggers of this PlaybookTask.  # noqa: E501
        :rtype: list[TimerTrigger]
        """
        return self._timer_triggers

    @timer_triggers.setter
    def timer_triggers(self, timer_triggers):
        """Sets the timer_triggers of this PlaybookTask.

        SLA fields  # noqa: E501

        :param timer_triggers: The timer_triggers of this PlaybookTask.  # noqa: E501
        :type: list[TimerTrigger]
        """

        self._timer_triggers = timer_triggers

    @property
    def type(self):
        """Gets the type of this PlaybookTask.  # noqa: E501


        :return: The type of this PlaybookTask.  # noqa: E501
        :rtype: TaskType
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this PlaybookTask.


        :param type: The type of this PlaybookTask.  # noqa: E501
        :type: TaskType
        """

        self._type = type

    @property
    def view(self):
        """Gets the view of this PlaybookTask.  # noqa: E501


        :return: The view of this PlaybookTask.  # noqa: E501
        :rtype: TaskView
        """
        return self._view

    @view.setter
    def view(self, view):
        """Sets the view of this PlaybookTask.


        :param view: The view of this PlaybookTask.  # noqa: E501
        :type: TaskView
        """

        self._view = view

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(PlaybookTask, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PlaybookTask):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
